.ConfirmModal__footer{display:flex;justify-content:end;padding:32px 0}.ConfirmModal__footer .checkbox{margin-right:auto}

/*# sourceMappingURL=main.css.map */

.app__body .shortcut-key{display:inline-block;padding:10px 9px 8px 8px;border-radius:4px;background:var(--center-channel-color);color:var(--center-channel-bg);font-size:14px;font-weight:500;line-height:1}.app__body .shortcut-key.shortcut-key--contrast{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.app__body .shortcut-key.shortcut-key--tooltip{padding:2px 5px;background-color:hsla(0,0%,100%,.08);color:hsla(0,0%,100%,.75);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.app__body .shortcut-key.shortcut-key--tutorial-tip{padding:2px 5px;background-color:rgba(var(--button-color-rgb), 0.08);color:rgba(var(--button-color-rgb), 0.75);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.app__body .shortcut-key.shortcut-key--shortcut-modal{font-family:inherit;font-size:12px;font-weight:600;line-height:16px}.console__body .shortcut-key{display:inline-block;border-radius:4px}.console__body .shortcut-key.shortcut-key--tooltip{padding:2px 5px;background-color:hsla(0,0%,100%,.08);color:hsla(0,0%,100%,.72);font-family:inherit;font-size:12px;font-weight:600;line-height:16px}
.tooltipContainer{z-index:1350;max-width:220px;padding:4px 8px;border-radius:4px;background:#000;box-shadow:0 6px 14px rgba(0,0,0,.12);line-height:18px;pointer-events:none;text-align:center;word-break:break-word}.tooltipContainer>.tooltipContent{display:flex;flex-direction:column;align-items:center;justify-content:center;font-family:"Open Sans",sans-serif}.tooltipContainer>.tooltipContent>.tooltipContentTitleContainer{display:flex;flex-direction:row;align-items:center;justify-content:center;gap:6px}.tooltipContainer>.tooltipContent>.tooltipContentTitleContainer.isEmojiLarge{flex-direction:column;gap:2px}.tooltipContainer>.tooltipContent>.tooltipContentTitleContainer.isEmojiLarge>.tooltipContentEmoji{padding-top:1px}.tooltipContainer>.tooltipContent>.tooltipContentTitleContainer>.tooltipContentEmoji{display:flex;align-items:center;justify-content:center}.tooltipContainer>.tooltipContent>.tooltipContentTitleContainer>.tooltipContentTitle{color:#fff;font-size:12px;font-weight:600;line-height:15px}.tooltipContainer>.tooltipContent>.tooltipContentShortcut{display:flex;flex-direction:row;align-items:center;justify-content:center;padding:4px 0;gap:2px}.tooltipContainer>.tooltipContent>.tooltipContentHint{color:hsla(0,0%,100%,.64);font-size:11px;font-weight:600;line-height:16px}
.Avatar{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:sub}.Avatar,.Avatar:focus,.Avatar.a11y--focused{border-radius:50%}.Avatar.Avatar-xxs{width:16px;min-width:16px;height:16px;font-size:8px}.Avatar.Avatar-xs{width:20px;min-width:20px;height:20px;font-size:9.5px}.Avatar.Avatar-sm{width:24px;min-width:24px;height:24px;font-size:10px}.Avatar.Avatar-md{width:32px;min-width:32px;height:32px;font-size:12px}.Avatar.Avatar-lg{width:36px;min-width:36px;height:36px;font-size:14px}.Avatar.Avatar-xl{width:50px;min-width:50px;height:50px;font-size:18px}.Avatar.Avatar-xxl{width:128px;min-width:128px;height:128px;font-size:44px}.Avatar.Avatar-plain{position:relative;display:inline-flex;align-items:center;justify-content:center;background:#fff}.Avatar.Avatar-plain::before{position:absolute;display:inline-flex;width:100%;height:100%;align-items:center;justify-content:center;border-radius:50%;color:rgba(var(--center-channel-color-rgb), 0.75);content:attr(data-content)}
.info-toast{position:fixed;z-index:99;display:grid;width:fit-content;min-height:40px;align-items:center;padding:8px;border-radius:4px;background:rgb(var(--center-channel-color-rgb));box-shadow:0 4px 6px rgba(0,0,0,.12);color:rgb(var(--center-channel-bg-rgb));font-weight:600;grid-template-columns:min-content auto min-content auto;line-height:20px}.info-toast .info-toast__icon_button{border:none;background:none;color:inherit}.info-toast span{padding-left:4px}.info-toast>div{display:flex;align-items:center}.info-toast>div .Icon{font-size:16px}.info-toast--top-left{top:16px;left:16px}.info-toast--top-left.toast-appear{transform:translateY(-150px)}.info-toast--top-left.toast-appear-active{transform:translateY(0)}.info-toast--top-center{top:16px;left:50%;transform:translateX(-50%)}.info-toast--top-center.toast-appear{transform:translate(-50%, -150px)}.info-toast--top-center.toast-appear-active{transform:translate(-50%, 0)}.info-toast--top-right{top:16px;right:16px}.info-toast--top-right.toast-appear{transform:translateY(-150px)}.info-toast--top-right.toast-appear-active{transform:translateY(0)}.info-toast--bottom-left{bottom:16px;left:16px}.info-toast--bottom-left.toast-appear{transform:translateY(150px)}.info-toast--bottom-left.toast-appear-active{transform:translateY(0)}.info-toast--bottom-center{bottom:16px;left:50%;transform:translateX(-50%)}.info-toast--bottom-center.toast-appear{transform:translate(-50%, 150px)}.info-toast--bottom-center.toast-appear-active{transform:translate(-50%, 0)}.info-toast--bottom-right{right:16px;bottom:16px}.info-toast--bottom-right.toast-appear{transform:translateY(150px)}.info-toast--bottom-right.toast-appear-active{transform:translateY(0)}.info-toast__undo{display:flex;height:24px;align-items:center;padding:6px 10px;border:none;border-radius:4px;margin-right:16px;margin-left:8px;background:var(--button-bg);color:var(--sidebar-text);font-size:11px;font-weight:600;line-height:10px}.toast-appear{opacity:0}.toast-appear-active{opacity:1;transition:all 500ms ease}
.FullScreenModal{position:fixed;z-index:1030 !important;top:0;left:0;overflow:auto;width:100%;height:100%;background:var(--center-channel-bg)}.FullScreenModal .close-x,.FullScreenModal .back{position:fixed;z-index:9;top:48px;width:40px;height:40px;padding:0;border:0;background:none;cursor:pointer}.FullScreenModal .close-x svg,.FullScreenModal .back svg{width:40px;height:40px;padding:4px;border-radius:4px;fill:rgba(var(--center-channel-color-rgb), 0.75)}.FullScreenModal .close-x svg:hover,.FullScreenModal .back svg:hover{background:rgba(var(--center-channel-color-rgb), 0.08);fill:rgba(var(--center-channel-color-rgb), 0.75)}.FullScreenModal .close-x svg:active,.FullScreenModal .back svg:active{background:rgba(var(--button-bg-rgb), 0.08);fill:var(--button-bg)}.FullScreenModal .close-x{right:48px}.FullScreenModal .back{left:48px}.FullScreenModal-enter,.FullScreenModal-appear{opacity:0}.FullScreenModal-enter-active,.FullScreenModal-appear-active{opacity:1;transition:opacity 100ms}.FullScreenModal-exit{opacity:1}.FullScreenModal-exit-active{opacity:0;transition:opacity 100ms}.FullScreenModal.FullScreenModal--compact .back{top:8px;left:16px}.FullScreenModal.FullScreenModal--compact .close-x{top:8px;right:16px}.FullScreenModal.FullScreenModal--compact .close-x,.FullScreenModal.FullScreenModal--compact .back{position:absolute}
.MenuGroup.menu-divider{height:1px;margin:8px 0;background:rgba(var(--center-channel-color-rgb), 0.08)}
.Menu .MenuHeader{display:flex;overflow:hidden;width:100%;height:32px;align-items:center;padding:0 32px 0 20px;clear:both;color:inherit;cursor:default;font-weight:600;text-align:left;text-overflow:ellipsis;white-space:nowrap}
.container-slider{position:relative;overflow:hidden;width:100%;min-width:400px;height:100%;min-height:450px}@media screen and (max-width: 700px){.container-slider .container-slider{margin:10px}}.container-slider .slide{position:absolute;z-index:0;width:100%;height:100%;opacity:0;transition:opacity ease-in-out .4s}.container-slider .slide img{width:100%;height:100%;object-fit:cover}.container-slider .active-anim{z-index:1;opacity:1}.container-slider .chevron-button{z-index:2;margin-top:120px;color:var(--center-channel-color);cursor:pointer;font-size:24px}.container-slider .chevron-button.disabled{opacity:.5}.container-slider .chevron-button.chevron-right{position:absolute;right:0}.container-slider .chevron-button.chevron-left{position:absolute;left:0}.container-slider .container-footer{position:absolute;z-index:2;bottom:0;display:flex;width:100%;align-items:center;justify-content:flex-start;padding:24px 0}.container-slider .container-footer .container-buttons{margin-left:auto}.container-slider .container-footer .container-buttons .btn-slide{position:absolute;display:flex;width:60px;height:20px;align-items:center;justify-content:center;border:1px solid rgba(34,34,34,.287);cursor:pointer;font-size:12px;font-weight:600}.container-slider .container-footer .container-buttons .disabled{opacity:.5;text-decoration:none}.container-slider .container-footer .container-buttons .prev,.container-slider .container-footer .container-buttons .next{left:20px;transform:translateY(-60%)}.container-slider .container-footer .container-dots{display:flex}.container-slider .container-footer .container-dots .dot{width:8px;height:8px;border-radius:50%;margin:0 5px;background:rgba(var(--button-bg-rgb), 0.25)}.container-slider .container-footer .container-dots .dot.active{width:6px;height:6px;margin-top:1px;background:var(--button-bg);box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.4)}
.TrialBenefitsModalStepMore.learn-more-button{display:block;width:fit-content;padding:13px 20px;border:none;border-radius:4px;margin-top:16px;background:var(--sys-center-channel-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModalStepMore.learn-more-button:hover:not(.disabled){background:rgba(var(--sys-button-bg-rgb), 0.04);text-decoration:none}.TrialBenefitsModalStepMore.learn-more-button:active{background:rgba(var(--sys-button-bg-rgb), 0.08);text-decoration:none}.TrialBenefitsModalStepMore.learn-more-button:focus{box-shadow:inset 0 0 0 2px var(--sys-button-bg);text-decoration:none}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.TrialBenefitsModalStep.slide-container{padding:0 24px}.TrialBenefitsModalStep.slide-container .svg-wrapper{display:flex;min-height:200px;flex:1;align-items:center;justify-content:center;margin-top:10px}.TrialBenefitsModalStep.slide-container .title{width:100%;margin:0 auto;margin-top:10px 0;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.TrialBenefitsModalStep.slide-container .description{width:100%;margin:0 auto;margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.TrialBenefitsModalStep.slide-container .bottom-text-left-message{position:fixed;bottom:24px;left:24px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.TrialBenefitsModalStep.slide-container.trial-just-started .title{text-align:center}.TrialBenefitsModalStep.slide-container.trial-just-started .description{font-size:12px}.TrialBenefitsModalStep.slide-container.trial-just-started .svg-wrapper{min-height:180px;margin-top:0}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper{display:flex;justify-content:flex-end;margin-top:10px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button{display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px;height:32px;font-size:12px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i{display:flex;font-size:18px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i:first-child::before{margin:0 7px 0 0}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .tertiary-button i:last-child::before{margin:0 0 0 7px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:32px;padding:0 16px;font-size:12px;line-height:10px;margin-left:8px}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.TrialBenefitsModalStep.slide-container.trial-just-started .buttons-section-wrapper .primary-button i{display:flex;font-size:18px}
.TrialBenefitsModal.modal-dialog{margin-top:calc(50vh - 240px)}.TrialBenefitsModal .modal-content{min-height:440px;padding:0 !important;border-color:rgba(var(--center-channel-color-rgb), 0.16);border-radius:8px;background:var(--center-channel-bg);color:var(--center-channel-color)}.TrialBenefitsModal .modal-header{height:48px;min-height:48px;padding:0;border:0;border-radius:8px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.TrialBenefitsModal .modal-header .close{top:6px;right:4px;width:4rem;height:4rem;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.TrialBenefitsModal .modal-header .close:hover,.TrialBenefitsModal .modal-header .close:active,.TrialBenefitsModal .modal-header .close:focus,.TrialBenefitsModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);opacity:1}.TrialBenefitsModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-bottom:24px !important}.TrialBenefitsModal .modal-body .buttons{text-align:center}.TrialBenefitsModal .modal-body .buttons .previous-btn{height:30px;align-items:center;align-self:center;padding:8px 16px;border:none;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModal .modal-body .buttons .previous-btn:hover,.TrialBenefitsModal .modal-body .buttons .previous-btn:active,.TrialBenefitsModal .modal-body .buttons .previous-btn:focus,.TrialBenefitsModal .modal-body .buttons .previous-btn:active:focus{border:none;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08)}.TrialBenefitsModal .modal-body .buttons .next-btn{height:30px;flex:none;padding:8px 16px;border:none;border-radius:4px;margin-left:8px;background:var(--button-bg);color:var(--sys-button-color);font-size:14px;font-weight:600;line-height:14px}.TrialBenefitsModal .modal-body .buttons .next-btn:hover,.TrialBenefitsModal .modal-body .buttons .next-btn:active,.TrialBenefitsModal .modal-body .buttons .next-btn:focus,.TrialBenefitsModal .modal-body .buttons .next-btn:active:focus{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.TrialBenefitsModal .modal-centered{text-align:center}.TrialBenefitsModal .modal-footer{padding:12px 24px 24px;border:none;border-radius:4px}
.Menu .MenuItem{display:flex;width:100%;align-items:center;font-size:14px}.Menu .MenuItem.MenuItem--with-icon .MenuItem__help-text{padding-left:28px}.Menu .MenuItem .destructive{color:var(--error-text)}.Menu .MenuItem .MenuItem__icon{width:20px;margin-right:8px;text-align:center}.Menu .MenuItem .MenuItem__compass-icon{margin:4px -6px;color:rgba(var(--center-channel-color-rgb), 0.64);fill:rgba(var(--center-channel-color-rgb), 0.64)}.Menu .MenuItem .MenuItem__compass-icon-dangerous{margin:4px -6px}.Menu .MenuItem .MenuItem__opacity{opacity:.73}.Menu .MenuItem span.icon{display:inline-block;width:28px;height:16px;align-self:center;padding-right:12px;line-height:16px}.Menu .MenuItem div.text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.Menu .MenuItem span.MenuItem__primary-text{display:inline-flex;max-width:100%;align-items:center;padding:5px 0;line-height:22px;white-space:nowrap}.Menu .MenuItem span.MenuItem__text-color{color:rgba(var(--center-channel-color-rgb), 0.75)}.Menu .MenuItem span.MenuItem__help-text{display:block;padding-bottom:8px;font-size:12px;line-height:16px;opacity:.7;white-space:nowrap}@media(max-width: 768px){.Menu .MenuItem span.MenuItem__help-text{padding-left:28px !important}.mobile-main-menu .Menu .MenuItem span.MenuItem__help-text{padding-left:36px !important}}.Menu .MenuItem>div,.Menu .MenuItem>button,.Menu .MenuItem>a{display:block;overflow:hidden;width:100%;align-items:center;padding:1px 16px;clear:both;color:inherit;cursor:pointer;font-weight:normal;line-height:28px;text-align:left;text-overflow:ellipsis;white-space:nowrap}.Menu .MenuItem>div i.icon,.Menu .MenuItem>button i.icon,.Menu .MenuItem>a i.icon{padding:0 3px;margin-right:4px;margin-bottom:2px;color:rgba(var(--center-channel-color-rgb), 0.64);vertical-align:middle}.Menu .MenuItem>div i.icon::before,.Menu .MenuItem>button i.icon::before,.Menu .MenuItem>a i.icon::before{margin:0}.Menu .MenuItem>div i.icon+span.MenuItem__primary-text,.Menu .MenuItem>button i.icon+span.MenuItem__primary-text,.Menu .MenuItem>a i.icon+span.MenuItem__primary-text{padding:5px 4px}.Menu .MenuItem>div.disabled,.Menu .MenuItem>button.disabled,.Menu .MenuItem>a.disabled{color:rgba(var(--center-channel-color-rgb), 0.48);cursor:default;pointer-events:none}.Menu .MenuItem>div.disabled:hover,.Menu .MenuItem>button.disabled:hover,.Menu .MenuItem>a.disabled:hover{background:none}.Menu .MenuItem>div.disabled .icon,.Menu .MenuItem>button.disabled .icon,.Menu .MenuItem>a.disabled .icon{color:rgba(var(--center-channel-color-rgb), 0.48)}.Menu .MenuItem>div.MenuItem__with-help,.Menu .MenuItem>button.MenuItem__with-help,.Menu .MenuItem>a.MenuItem__with-help{display:block;height:auto}.Menu .MenuItem>div.MenuItem__with-help .MenuItem__primary-text,.Menu .MenuItem>button.MenuItem__with-help .MenuItem__primary-text,.Menu .MenuItem>a.MenuItem__with-help .MenuItem__primary-text{padding:7px 0 3px}@media(max-width: 768px){.Menu .MenuItem>div.MenuItem__with-help .icon,.Menu .MenuItem>button.MenuItem__with-help .icon,.Menu .MenuItem>a.MenuItem__with-help .icon{top:10px}}.Menu .MenuItem>div.MenuItem__with-sibling,.Menu .MenuItem>button.MenuItem__with-sibling,.Menu .MenuItem>a.MenuItem__with-sibling{padding-right:0 !important}.Menu .MenuItem>div.MenuItem__with-sibling.disabled,.Menu .MenuItem>button.MenuItem__with-sibling.disabled,.Menu .MenuItem>a.MenuItem__with-sibling.disabled{color:rgba(var(--center-channel-color-rgb), 0.48);cursor:default;pointer-events:none}.Menu .MenuItem>div.MenuItem__with-sibling.disabled:hover,.Menu .MenuItem>button.MenuItem__with-sibling.disabled:hover,.Menu .MenuItem>a.MenuItem__with-sibling.disabled:hover{background:none}.Menu .MenuItem>div.MenuItem__with-sibling.disabled .icon,.Menu .MenuItem>button.MenuItem__with-sibling.disabled .icon,.Menu .MenuItem>a.MenuItem__with-sibling.disabled .icon{color:rgba(var(--center-channel-color-rgb), 0.48)}.Menu .MenuItem>div .MenuItem__icon,.Menu .MenuItem>button .MenuItem__icon,.Menu .MenuItem>a .MenuItem__icon{display:inline-flex;width:20px;height:20px;align-items:center;justify-content:center;margin-right:8px}.Menu .MenuItem>div.MenuItem__dangerous,.Menu .MenuItem>button.MenuItem__dangerous,.Menu .MenuItem>a.MenuItem__dangerous{color:var(--dnd-indicator)}.Menu .MenuItem>div.MenuItem__dangerous i,.Menu .MenuItem>button.MenuItem__dangerous i,.Menu .MenuItem>a.MenuItem__dangerous i{color:var(--dnd-indicator) !important}.Menu .MenuItem>div.MenuItem__dangerous:is(:hover,:active,:focus),.Menu .MenuItem>button.MenuItem__dangerous:is(:hover,:active,:focus),.Menu .MenuItem>a.MenuItem__dangerous:is(:hover,:active,:focus){background-color:var(--dnd-indicator) !important;color:var(--button-color)}.Menu .MenuItem>div.MenuItem__dangerous:is(:hover,:active,:focus) i,.Menu .MenuItem>button.MenuItem__dangerous:is(:hover,:active,:focus) i,.Menu .MenuItem>a.MenuItem__dangerous:is(:hover,:active,:focus) i{color:var(--button-color) !important}.Menu .MenuItem>a{text-decoration:none}.Menu .MenuItem>a:focus,.Menu .MenuItem>a:hover{color:inherit}.Menu .MenuCloudTrial{padding:8px 12px;border-radius:4px;margin:8px;margin-top:0}.Menu .MenuCloudTrial__free-trial__content-title{margin:4px 0;font-weight:600;line-height:20px}.Menu .MenuCloudTrial__free-trial__content-section{display:flex}.Menu .MenuCloudTrial__free-trial__content-section__icon-section{margin-top:-2px;color:var(--button-bg);font-size:18px}.Menu .MenuCloudTrial .upgradeLink{color:var(--button-bg);font-style:normal;font-weight:600}.Menu .MenuCloudTrial .upgradeLink:hover{color:var(--button-bg);font-style:normal;font-weight:600;text-decoration:none}.Menu .MenuCloudTrial .style-link{display:inline-block;min-width:fit-content;border:none;background:none;color:var(--button-bg);font-weight:600}.Menu .MenuCloudTrial .style-link:hover:not(.disabled){border:none;background:none;color:var(--button-bg);text-decoration:underline}.Menu .MenuCloudTrial .open-trial-benefits-modal{display:inline !important;margin-left:2px}.Menu .MenuCloudTrial .open-see-plans-modal{display:block}.Menu .MenuItemCloudLimit{padding:16px 20px;margin-top:0;background-color:rgba(var(--mention-highlight-bg-rgb), 0.16)}.Menu .MenuItemCloudLimit--critical{background-color:rgba(var(--error-text-color-rgb), 0.16)}.Menu .MenuItemCloudLimit .icon-information-outline{color:var(--button-bg);cursor:pointer}.Menu .MenuItemCloudLimit a{color:var(--button-bg) !important;font-weight:bold;text-decoration:none}.Menu .MenuItemCloudLimit a:hover{background:inherit !important}.Menu .MenuItemCloudLimit__title{display:flex;align-items:center;padding-bottom:5px;color:var(--center-channel-color);font-size:14px;font-weight:bold}.Menu .MenuItemCloudLimit__description{padding-bottom:12px;font-size:12px}.Menu .MenuItemCloudLimit__usage{display:flex;align-items:center}.Menu .MenuItemCloudLimit__usage-label{padding-left:18px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px;font-weight:bold}.Menu .MenuStartTrial{display:flex;flex-direction:column;align-items:flex-start;padding:8px 20px;border-radius:4px;margin-top:0;font-size:12px;line-height:16px}.Menu .MenuStartTrial button{padding:3px 0;border:none;background-color:rgba(0,0,0,0);color:var(--link-color);font-style:normal;font-weight:600}.Menu .MenuStartTrial button:hover{background:rgba(0,0,0,0);text-decoration:underline}.Menu .MenuStartTrial .editionText{position:relative;width:100%}.Menu .MenuStartTrial .editionText a{color:var(--link-color)}.Menu .MenuStartTrial .editionText a:hover{background:none}.SubMenu{position:absolute;top:unset;left:unset;padding-left:0;cursor:auto}.SubMenu__icon-left{position:relative;top:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:19px}.SubMenu__icon-left-empty{position:relative;top:0;display:none;width:0;font-size:19px;visibility:hidden}.SubMenu__icon-right{padding-top:3px;color:rgba(var(--center-channel-color-rgb), 0.64);float:right;font-size:19px}.SubMenu__icon-right-empty{top:0;display:none;width:0;padding:0;margin-left:auto;font-size:19px}.MenuItem__divider{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:8px 0}
.WorkspaceLimitLine{display:flex;align-items:center;padding-bottom:16px;font-weight:600}.WorkspaceLimitLine:last-child{padding-bottom:0}.WorkspaceLimitLine__icon{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:24px}.WorkspaceLimitLine__bar{flex-grow:1;padding-right:24px;padding-left:12px;color:rgba(var(--center-channel-color-rgb), 0.75)}.WorkspaceLimitLine__bar:first-child{padding-left:0}.WorkspaceLimitLine__bar-label{padding-bottom:4px}.WorkspaceLimitLine__text-status{flex-basis:121px;align-self:end;color:var(--center-channel-color);font-size:11px;line-height:11px}
.CloudUsageModal .GenericModal__body{color:var(--center-channel-color)}.CloudUsageModal__description{padding-bottom:24px;margin-bottom:0}.CloudUsageModal .modal-content{background-color:var(--center-channel-bg)}.CloudUsageModal .modal-body{color:var(--center-channel-color)}.CloudUsageModal .modal-body:not(:last-child){padding-bottom:28px !important;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.cloud-usage-backdrop{z-index:1050}
.Menu{z-index:10000}.Menu .dropdown-menu{display:block;min-width:225px;max-width:270px;max-height:80vh;padding:8px 0;border:solid 1px rgba(var(--center-channel-color-rgb), 0.12);border-radius:var(--radius-s);background-color:var(--center-channel-bg);box-shadow:var(--elevation-4)}.Menu .dropdown-menu ul{padding:8px 0;margin:0}.Menu .dropdown-menu li{list-style:none}.Menu .dropdown-menu li a{color:inherit}.Menu.Menu-enter .dropdown-menu{opacity:0}@media screen and (min-width: 768px){.Menu.Menu-enter .dropdown-menu{overflow:hidden;max-height:0;overflow-y:hidden}}.Menu.Menu-enter-active .dropdown-menu{opacity:1}@media screen and (min-width: 768px){.Menu.Menu-enter-active .dropdown-menu{max-height:80vh;overflow-y:hidden;transition:max-height 1000ms ease-in,opacity 250ms linear}}@media screen and (max-width: 640px){.Menu.Menu-enter-active .dropdown-menu{transition:opacity 1000ms linear}}.Menu.Menu-enter-done .dropdown-menu{opacity:1}@media screen and (min-width: 768px){.Menu.Menu-enter-done .dropdown-menu{max-height:80vh;overflow-y:auto}}.Menu.Menu-exit .dropdown-menu{opacity:0}@media screen and (min-width: 768px){.Menu.Menu-exit .dropdown-menu{max-height:0;overflow-y:hidden;transition:max-height 1000ms ease-in 0ms,opacity 250ms linear 750ms}}@media screen and (max-width: 768px){.Menu.Menu-exit .dropdown-menu{transition:opacity 1000ms linear}}.Menu #ChannelMenu-moveToDivider{height:1px;padding:0;margin:8px 0;background:rgba(var(--center-channel-color-rgb), 0.08);pointer-events:none}.Menu #ChannelMenu-moveToDivider span{display:none}@media screen and (max-width: 768px){.Menu #ChannelMenu-moveToDivider{background:none}.Menu #ChannelMenu-moveToDivider .menu-divider{margin:0}}.Menu .SubMenuItemContainer:not(.hasDivider){display:flex;align-items:center;justify-content:space-between}.Menu .styleSelectableItem .MenuItem{width:100%}.Menu .styleSelectableItem .MenuItem div:hover,.Menu .styleSelectableItem .MenuItem div:focus{background:none !important}.Menu .styleSelectableItem .SubMenu__icon-right{padding:0 9px 0 8px;margin-right:0;line-height:28px}.Menu .styleSelectableItem .SubMenu__icon-right.mobile{padding:0 4px 0 9px}.Menu .styleSelectableItem .styleSelectableItemDiv{display:flex;height:34px;align-items:center;justify-content:space-between;padding:0 15px;margin:0}.Menu .styleSelectableItem .grid{display:grid;width:100%;grid-template-columns:auto 1fr auto auto}.Menu .styleSelectableItem .flex{width:100%}.Menu .styleSelectableItem .sorting-menu-checkbox{width:0;padding-right:30px}.Menu .styleSelectableItem .sorting-menu-checkbox i{color:var(--button-bg)}.Menu>.product-switcher-menu .MenuItem .MenuItem__primary-text{line-height:26px}.Menu>.product-switcher-menu .MenuItem a,.Menu>.product-switcher-menu .MenuItem button{padding:0 20px}.Menu>.product-switcher-menu .MenuItem a .icon,.Menu>.product-switcher-menu .MenuItem button .icon{color:rgba(var(--center-channel-color-rgb), 0.64)}.Menu__content.openLeft{right:0;left:inherit}@media screen and (min-width: 768px){.Menu__content.openUp{top:auto;bottom:100%}}
.MenuWrapper{position:relative}.MenuWrapper *:first-child{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none}div[disabled]{opacity:.7;pointer-events:none}.MenuWrapperAnimation-enter{opacity:0}.MenuWrapperAnimation-enter-active,.MenuWrapperAnimation-enter-done,.MenuWrapperAnimation-exit{opacity:1}.MenuWrapperAnimation-exit-active,.MenuWrapperAnimation-exit-done{opacity:0}body.enable-animations .MenuWrapperAnimation-enter-active,body.enable-animations .MenuWrapperAnimation-exit-active{transition-duration:80ms;transition-property:opacity}
@media screen and (max-width: 768px){#submenuModal{padding:0}#submenuModal .mobile-sub-menu{max-width:100% !important;height:100%;margin-top:0 !important}#submenuModal .mobile-sub-menu .modal-content{height:100%;padding:0;border:unset;background:rgba(0,0,0,0) !important;box-shadow:unset}#submenuModal .mobile-sub-menu .modal-content .modal-body{overflow:unset;height:100%;max-height:unset;padding:0}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper{height:100%}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper div{height:100%}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu{padding:0 1.5em}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu{position:relative;top:0;display:flex;width:100%;max-width:inherit;height:100%;max-height:inherit;flex-direction:column;justify-content:center;padding-top:0;border:0;margin-bottom:0;background:rgba(0,0,0,0);box-shadow:none;color:inherit;list-style:none}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu button,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu a,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu a:hover{opacity:.8}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem{background:var(--center-channel-bg)}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>button,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem>a{width:100%;height:auto;padding:15px 20px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);font-size:14px;opacity:1;text-align:left}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem:first-child div,#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuItem:first-child button{border:none}#submenuModal .mobile-sub-menu .modal-content .modal-body .MenuWrapper .Menu.dropdown-menu .MenuGroup.menu-divider{background:#fff}}
.LearnMoreTrialModalStep.slide-container{padding:0 24px;color:var(--center-channel-color)}.LearnMoreTrialModalStep.slide-container .svg-wrapper{display:flex;min-height:200px;flex:1;align-items:center;justify-content:center;margin-top:-10px}.LearnMoreTrialModalStep.slide-container .pre-title{margin-top:19px;margin-bottom:8px;font-family:Metropolis,sans-serif;font-size:16px;line-height:24px}.LearnMoreTrialModalStep.slide-container .title{width:100%;margin:0 auto;margin-top:10px 0;font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.LearnMoreTrialModalStep.slide-container .description{width:100%;margin:0 auto;margin-top:8px;font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.LearnMoreTrialModalStep.slide-container .disclaimer{width:90%;height:32px;margin-top:15px;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:normal;line-height:16px}.LearnMoreTrialModalStep.slide-container .bottom-text-left-message{position:fixed;bottom:24px;left:24px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-style:normal;font-weight:normal;line-height:16px}
.DropdownInput.Input_container{margin-top:20px}.DropdownInput .Input_wrapper{padding:0 1px}.DropdownInput .Input{font-size:14px;line-height:20px}.DropdownInput .Input.Input___focus .a11y--focused{box-shadow:none}.DropdownInput .Input_legend{margin-left:8px}.DropdownInput__controlContainer .DropDown__control{background-color:var(--center-channel-bg)}.DropDown__menu{background-color:var(--center-channel-bg) !important}.DropDown__menu-list>.DropDown__group:first-child .DropDown__group-heading{display:none}.DropDown__single-value{color:var(--center-channel-color) !important}.DropdownInput__indicatorsContainer{margin-right:8px}.DropdownInput__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.DropdownInput__indicatorsContainer i::before{margin:0}.DropdownInput__option>div{z-index:999999;padding:10px 24px;cursor:pointer;line-height:16px}.DropdownInput__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.DropdownInput__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.second-dropdown-sibling-wrapper .DropdownInput{z-index:999998}.second-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999998}.third-dropdown-sibling-wrapper .DropdownInput{z-index:999997}.third-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999997}.fourth-dropdown-sibling-wrapper .DropdownInput{z-index:999996}.fourth-dropdown-sibling-wrapper .DropdownInput__option>div{z-index:999996}
.error,.Input_container .Input___error{color:var(--error-text)}.info{color:var(--sidebar-text-active-border)}.warning,.Input_container .Input___warning{color:var(--away-indicator-dark)}.success,.Input_container .Input___success{color:var(--online-indicator)}.Input_container{width:100%}.Input_container textarea{resize:none}.Input_container .Input{position:relative;left:0;width:100%;padding:0;border:0;border-radius:4px;box-shadow:none;color:var(--center-channel-color);font-size:14px;line-height:20px;outline:0}.Input_container .Input::placeholder{color:rgba(var(--center-channel-color-rgb), 0.75)}.Input_container .Input.Input__focus{box-shadow:none}.Input_container .Input.large{height:42px;font-size:16px;line-height:24px}.Input_container .Input_wrapper{display:flex;flex:1;align-items:center;padding:0 16px;margin:2px 0;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:14px;line-height:20px}.Input_container .Input_wrapper>:not(:first-child){margin-left:8px}.Input_container .Input_wrapper textarea{margin-top:6px}.Input_container .Input_wrapper .form-control[disabled]{background:none;cursor:not-allowed;opacity:.6}.Input_container .Input_wrapper .form-control:focus{box-shadow:none !important}.Input_container .Input_limit-exceeded{align-self:center;margin-left:16px;color:var(--error-text);font-size:14px;line-height:20px}.Input_container .Input-border-error{border-color:var(--error-text)}.Input_container .Input___error,.Input_container .Input___customMessage,.Input_container .Input___info{margin-top:5px;font-size:12px;line-height:16px;text-align:left}.Input_container .Input___error i,.Input_container .Input___customMessage i,.Input_container .Input___info i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.Input_container .Input___error i::before,.Input_container .Input___customMessage i::before,.Input_container .Input___info i::before{margin:0}.Input_container .Input___error{display:flex}.Input_container .Input___warning{display:flex}.Input_container .Input___success{display:flex}.Input_container .Input___info{color:rgba(var(--center-channel-color-rgb), 0.75)}.Input_container .Input___info>span.valid{margin-left:7px}.Input_container .Input_fieldset{position:relative;display:flex;width:100%;box-sizing:border-box;padding:0 1px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;color:rgba(var(--secondary-blue-rgb), 0.4)}.Input_container .Input_fieldset:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.Input_container .Input_fieldset:focus-within{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg);color:var(--button-bg)}.Input_container .Input_fieldset:focus-within .Input_legend{color:var(--button-bg)}.Input_container .Input_fieldset___error{border-color:var(--error-text);color:var(--error-text)}.Input_container .Input_fieldset___error:focus-within{border-color:var(--error-text);box-shadow:inset 0 0 0 1px var(--error-text);color:var(--error-text)}.Input_container .Input_fieldset___error:focus-within .Input_legend{color:var(--error-text)}.Input_container .Input_fieldset___error:hover{border-color:var(--error-text)}.Input_container .Input_fieldset___error .Input_legend{color:var(--error-text)}.Input_container .Input_legend{position:absolute;z-index:1;top:-8px;display:flex;width:auto;padding:0 4px;border:none;margin-left:12px;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:10px;font-weight:normal;line-height:14px;opacity:0;transform:translateY(8px);transition-duration:.15s;transition-property:opacity,transform;transition-timing-function:ease-in-out;white-space:nowrap}.Input_container .Input_legend___focus{padding:0 4px;opacity:1;transform:translateY(0)}.Input_container.disabled .Input_fieldset{border-color:rgba(var(--center-channel-color-rgb), 0.16);background-color:rgba(var(--center-channel-color-rgb), 0.04)}.Input_container .Input__clear{display:flex;color:rgba(var(--center-channel-color), 0.68);cursor:pointer}
.AirGappedModal .modal-dialog{position:absolute;top:50%;left:50%;width:512px;height:660px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:12px;margin:auto;transform:translate(-50%, -50%) !important}.AirGappedModal .modal-content{border-radius:12px}.AirGappedModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;border-radius:12px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.AirGappedModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.AirGappedModal .modal-header .close:hover,.AirGappedModal .modal-header .close:active,.AirGappedModal .modal-header .close:focus,.AirGappedModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);opacity:1}.AirGappedModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.AirGappedModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-top:24px;padding-right:32px;padding-bottom:26px;padding-left:32px}.AirGappedModal .modal-body .description{margin:0 auto;margin-top:8px;color:rgb(var(--center-channel-color-rgb));font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:left}.AirGappedModal .modal-body .icon{width:100%;align-items:center;margin-top:32px;text-align:center}.AirGappedModal .modal-body .buttons{margin-top:32px;text-align:right}
.IconMessage .content{display:flex;flex-direction:column;align-content:center;justify-content:center;text-align:center}.IconMessage .content.success{padding-bottom:2px;padding-left:7px}.IconMessage .content.success>.IconMessage__svg-wrapper{margin-left:68px}.IconMessage .content .IconMessage-h3{margin-top:43px;color:var(--center-channel-color);font-size:24px;font-weight:600;line-height:32px}@media screen and (max-width: 600px){.IconMessage .content .IconMessage-h3{font-size:36px;letter-spacing:-0.13px;line-height:42px}}.IconMessage .content .IconMessage-sub{max-width:560px;align-self:center;margin-top:16px;color:var(--center-channel-color);font-size:14px;font-style:normal;font-weight:normal;line-height:20px}.IconMessage .content .IconMessage-sub.error{color:#db3214}.IconMessage .content .IconMessage-buttons{display:flex;height:40px;justify-content:center;margin-top:16px;font-size:14px;font-weight:600;gap:16px;line-height:14px;text-align:center}.IconMessage .content .IconMessage-progress{width:387px;height:4px;border-radius:4px;margin:0 auto;margin-top:90px;background:rgba(34,64,109,.12)}.IconMessage .content .IconMessage-progress-fill{height:100%;border-radius:4px;background:#0058cc}.IconMessage .content .IconMessage-button button{border-radius:4px;background:var(--button-bg);color:var(--button-color)}.IconMessage .content .IconMessage-tertiary-button button{border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.IconMessage .content .IconMessage-link{margin-top:21px;margin-left:-10px;color:#0058cc;font-size:14px;font-weight:600;line-height:14px;text-align:center}.IconMessage__svg-wrapper{align-self:center}@media screen and (max-width: 600px){.IconMessage__svg-wrapper svg{width:150%}}
.delete-workspace-result_modal .IconMessage{transform:translateY(50%)}.ResultModal__small .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.ResultModal__small .modal-header .close:hover,.ResultModal__small .modal-header .close:active,.ResultModal__small .modal-header .close:focus,.ResultModal__small .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);opacity:1}.ResultModal__small .modal-dialog{position:absolute;top:50%;left:50%;width:600px;height:360px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:8px;margin:auto;transform:translate(-50%, -50%) !important}.ResultModal__small .modal-dialog .modal-header{border:none;background:var(--center-channel-bg) !important}.ResultModal__small .modal-dialog .modal-content{height:100%;border-radius:8px}.ResultModal__small .modal-dialog .modal-content .IconMessage__svg-wrapper{margin-left:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-h3{margin-top:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-sub{max-width:504px;margin-top:0}.ResultModal__small .modal-dialog .modal-content .IconMessage-buttons{justify-content:right;padding-right:24px;margin-top:32px}.ResultModal__small .modal-dialog .modal-content .IconMessage-buttons .btn{font-family:"Open sans",sans-serif;font-size:12px;font-weight:600}
.StartTrialFormModal.error{display:none !important}.StartTrialFormModal .modal-dialog{position:absolute;top:50%;left:50%;width:512px;height:660px;border:1 px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:8px;margin:auto;transform:translate(-50%, -50%) !important}.StartTrialFormModal .modal-content{border-radius:8px}.StartTrialFormModal .modal-header{display:block;min-height:48px;padding-top:26px;padding-bottom:0;padding-left:32px;border:0;border-radius:8px;background:var(--center-channel-bg) !important;color:var(--center-channel-color)}.StartTrialFormModal .modal-header .close{top:26px;right:26px;width:24px;height:24px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75) !important;font-family:"Open Sans",sans-serif;font-size:32px;font-weight:400}.StartTrialFormModal .modal-header .close:hover,.StartTrialFormModal .modal-header .close:active,.StartTrialFormModal .modal-header .close:focus,.StartTrialFormModal .modal-header .close:active:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75);opacity:1}.StartTrialFormModal .modal-header .title{font-family:Metropolis,sans-serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:left}.StartTrialFormModal .modal-header .description{margin:0 auto;margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.StartTrialFormModal .modal-body{display:flex;overflow:scroll;width:100%;flex-direction:column;padding-top:32px;padding-right:32px;padding-bottom:26px;padding-left:32px}.StartTrialFormModal .modal-body .disclaimer{width:100%;height:32px;margin:0;margin-top:36px;margin-bottom:32px;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:normal;line-height:16px;text-align:left}.StartTrialFormModal .modal-body .email_input{margin-top:36px}.StartTrialFormModal .modal-body .company_name_input{margin-top:36px}.StartTrialFormModal .modal-body .DropdownInput{margin-top:36px}.StartTrialFormModal .modal-body .DropdownInput .DropDown__menu{max-height:124px}.StartTrialFormModal .modal-body .DropdownInput .DropDown__menu-list{max-height:124px}.StartTrialFormModal .modal-body .Input___error{height:100%;font-weight:600;line-height:16px}.StartTrialFormModal .modal-body .Input___error .icon.error.icon-alert-circle-outline{width:16px;height:16px;margin-right:4px;font-size:16px}.StartTrialFormModal .modal-body .countries-section{max-height:164px}.StartTrialFormModal .modal-body .buttons{margin-top:32px;text-align:right}.StartTrialFormModal .modal-centered{text-align:center}
.StartTrialBtn.embargoed{margin-top:5px;color:var(--error-text)}.StartTrialBtn.start-trial-btn{display:block;width:fit-content;padding:13px 20px;border:none;border-radius:4px;background:var(--sys-center-channel-bg);box-shadow:inset 0 0 0 1px var(--sys-button-bg);color:var(--sys-button-bg);font-size:14px;font-weight:600;line-height:14px}.StartTrialBtn.start-trial-btn:hover:not(.disabled){background:rgba(var(--sys-button-bg-rgb), 0.04);text-decoration:none}.StartTrialBtn.start-trial-btn:active{background:rgba(var(--sys-button-bg-rgb), 0.08);text-decoration:none}.StartTrialBtn.start-trial-btn:focus{box-shadow:inset 0 0 0 2px var(--sys-button-bg);text-decoration:none}
.MuiPopover-root.MuiModal-root.menu_menuStyled{z-index:1100}.MuiPopover-root.MuiModal-root.menu_menuStyled .MuiPaper-root{min-width:114px;max-width:496px;max-height:80vh;padding:4px 0;background-color:var(--center-channel-bg);box-shadow:var(--elevation-4),0 0 0 1px rgba(var(--center-channel-color-rgb), 0.12) inset;margin-block-start:4px}.MuiPopover-root.MuiModal-root.menu_menuStyled.AsSubMenu{pointer-events:none}.MuiPopover-root.MuiModal-root.menu_menuStyled.AsSubMenu .MuiPaper-root{box-shadow:var(--elevation-5),0 0 0 1px rgba(var(--center-channel-color-rgb), 0.12) inset}.menuModal .modal-header{display:none}.menuModal .GenericModal__body{padding:0}
.modal .StatusModal.GenericModal .StatusModal__clear-container.input-clear{position:absolute;top:16px;right:18px;color:rgba(var(--center-channel-color-rgb), 0.64);opacity:1}.StatusModal{width:600px}.StatusModal.modal-dialog{margin:auto}.modal .StatusModal.GenericModal .modal-body{overflow:visible}.modal .StatusModal.GenericModal .emoji-quick-input.form-control{height:4.8rem;padding:0 4.8rem;border-radius:4px;font-size:14px;font-weight:600}.modal .StatusModal.GenericModal .emoji-quick-input.form-control:focus{border-color:var(--button-bg)}.StatusModal .GenericModal__body{padding:0}.StatusModal .GenericModal__button.btn:disabled,.StatusModal .GenericModal__button.btn:disabled:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);opacity:1}.StatusModal__emoji-container{position:absolute;z-index:5;top:14px;left:40px;margin-right:2px}.StatusModal__emoji-button{display:flex;width:36px;height:36px;align-items:center;justify-content:center;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.64);fill:rgba(var(--center-channel-color-rgb), 0.64)}.StatusModal__emoji-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);fill:rgba(var(--center-channel-color-rgb), 0.8)}.StatusModal__emoji-button:active,.StatusModal__emoji-button--active,.StatusModal__emoji-button--active:hover{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.StatusModal__emoji-button svg{width:20px;height:20px}.StatusModal__footer{display:flex;align-items:center;justify-content:space-between;padding:2rem 0;text-align:right}.StatusModal__footer .btn{height:4rem;padding:0 2rem;border-radius:4px;font-size:14px;font-weight:600}.status-dropdown-menu .input-clear-x,.StatusModal__input .input-clear-x{color:rgba(var(--center-channel-color-rgb), 0.64)}.status-dropdown-menu .input-clear-x .icon,.StatusModal__input .input-clear-x .icon{font-size:20px}.status-dropdown-menu .MaxLengthInput__validation,.StatusModal__input .MaxLengthInput__validation{top:17px !important;right:44px !important}.status-dropdown-menu .MaxLengthInput.form-control.has-error,.StatusModal__input .MaxLengthInput.form-control.has-error{padding-right:76px !important}.ic-clear-search,.ic-search{position:absolute;z-index:1;background-position:center;background-repeat:no-repeat;cursor:pointer}.ic-clear-search{top:12px;right:12px;width:2rem;height:2rem}.statusSuggestion{overflow:auto;min-height:232px;max-height:264px}.statusSuggestion__content{display:flex;overflow:auto;width:100%;height:100%;flex-direction:column;border:none;box-shadow:none}.statusSuggestion__row{display:flex;width:100%;min-height:40px;align-items:center;padding-right:10px;padding-left:18px;border:none;background:rgba(0,0,0,0);color:var(--center-channel-color);font-size:inherit}.statusSuggestion__row:hover{border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}.statusSuggestion__row:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:v(button-bg)}.statusSuggestion__icon{margin-right:15px;margin-bottom:1px}.statusSuggestion__title{display:flex;height:24px;margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.55);font-size:12px;font-weight:600}.statusSuggestion__text{overflow:hidden;height:20px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.statusSuggestion__text.with_duration{max-width:62%}.statusSuggestion__duration{margin-left:8px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:14px;font-weight:400;line-height:14px}.suggestion-clear{margin-top:3px;margin-left:auto}#custom-status-tooltip p{margin:0}#custom-status-tooltip .custom-status{display:inline-block}#custom-status-tooltip .custom-status-expiry{color:hsla(0,0%,100%,.72);font-size:11px;font-weight:400}span.emoticon[style]:hover{opacity:1 !important}.statusExpiry{display:inline-block;margin:12px 0 24px 0;font-size:14px}.statusExpiry__menu{cursor:pointer}.statusExpiry__menu .expiry-value{margin-right:4px;font-weight:600}
.rdp {
  --rdp-cell-size: 40px;
  --rdp-accent-color: #0000ff;
  --rdp-background-color: #e7edff;
  --rdp-accent-color-dark: #3003e1;
  --rdp-background-color-dark: #180270;
  --rdp-outline: 2px solid var(--rdp-accent-color); /* Outline border for focused elements */
  --rdp-outline-selected: 3px solid var(--rdp-accent-color); /* Outline border for focused _and_ selected elements */

  margin: 1em;
}

/* Hide elements for devices that are not screen readers */
.rdp-vhidden {
  box-sizing: border-box;
  padding: 0;
  margin: 0;
  background: transparent;
  border: 0;
  -moz-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  position: absolute !important;
  top: 0;
  width: 1px !important;
  height: 1px !important;
  padding: 0 !important;
  overflow: hidden !important;
  clip: rect(1px, 1px, 1px, 1px) !important;
  border: 0 !important;
}

/* Buttons */
.rdp-button_reset {
  appearance: none;
  position: relative;
  margin: 0;
  padding: 0;
  cursor: default;
  color: inherit;
  background: none;
  font: inherit;

  -moz-appearance: none;
  -webkit-appearance: none;
}

.rdp-button_reset:focus-visible {
  /* Make sure to reset outline only when :focus-visible is supported */
  outline: none;
}

.rdp-button {
  border: 2px solid transparent;
}

.rdp-button[disabled]:not(.rdp-day_selected) {
  opacity: 0.25;
}

.rdp-button:not([disabled]) {
  cursor: pointer;
}

.rdp-button:focus-visible:not([disabled]) {
  color: inherit;
  background-color: var(--rdp-background-color);
  border: var(--rdp-outline);
}

.rdp-button:hover:not([disabled]):not(.rdp-day_selected) {
  background-color: var(--rdp-background-color);
}

.rdp-months {
  display: flex;
}

.rdp-month {
  margin: 0 1em;
}

.rdp-month:first-child {
  margin-left: 0;
}

.rdp-month:last-child {
  margin-right: 0;
}

.rdp-table {
  margin: 0;
  max-width: calc(var(--rdp-cell-size) * 7);
  border-collapse: collapse;
}

.rdp-with_weeknumber .rdp-table {
  max-width: calc(var(--rdp-cell-size) * 8);
  border-collapse: collapse;
}

.rdp-caption {
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 0;
  text-align: left;
}

.rdp-multiple_months .rdp-caption {
  position: relative;
  display: block;
  text-align: center;
}

.rdp-caption_dropdowns {
  position: relative;
  display: inline-flex;
}

.rdp-caption_label {
  position: relative;
  z-index: 1;
  display: inline-flex;
  align-items: center;
  margin: 0;
  padding: 0 0.25em;
  white-space: nowrap;
  color: currentColor;
  border: 0;
  border: 2px solid transparent;
  font-family: inherit;
  font-size: 140%;
  font-weight: bold;
}

.rdp-nav {
  white-space: nowrap;
}

.rdp-multiple_months .rdp-caption_start .rdp-nav {
  position: absolute;
  top: 50%;
  left: 0;
  transform: translateY(-50%);
}

.rdp-multiple_months .rdp-caption_end .rdp-nav {
  position: absolute;
  top: 50%;
  right: 0;
  transform: translateY(-50%);
}

.rdp-nav_button {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: var(--rdp-cell-size);
  height: var(--rdp-cell-size);
  padding: 0.25em;
  border-radius: 100%;
}

/* ---------- */
/* Dropdowns  */
/* ---------- */

.rdp-dropdown_year,
.rdp-dropdown_month {
  position: relative;
  display: inline-flex;
  align-items: center;
}

.rdp-dropdown {
  appearance: none;
  position: absolute;
  z-index: 2;
  top: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  margin: 0;
  padding: 0;
  cursor: inherit;
  opacity: 0;
  border: none;
  background-color: transparent;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

.rdp-dropdown[disabled] {
  opacity: unset;
  color: unset;
}

.rdp-dropdown:focus-visible:not([disabled]) + .rdp-caption_label {
  background-color: var(--rdp-background-color);
  border: var(--rdp-outline);
  border-radius: 6px;
}

.rdp-dropdown_icon {
  margin: 0 0 0 5px;
}

.rdp-head {
  border: 0;
}

.rdp-head_row,
.rdp-row {
  height: 100%;
}

.rdp-head_cell {
  vertical-align: middle;
  text-transform: uppercase;
  font-size: 0.75em;
  font-weight: 700;
  text-align: center;
  height: 100%;
  height: var(--rdp-cell-size);
  padding: 0;
}

.rdp-tbody {
  border: 0;
}

.rdp-tfoot {
  margin: 0.5em;
}

.rdp-cell {
  width: var(--rdp-cell-size);
  height: 100%;
  height: var(--rdp-cell-size);
  padding: 0;
  text-align: center;
}

.rdp-weeknumber {
  font-size: 0.75em;
}

.rdp-weeknumber,
.rdp-day {
  display: flex;
  overflow: hidden;
  align-items: center;
  justify-content: center;
  box-sizing: border-box;
  width: var(--rdp-cell-size);
  max-width: var(--rdp-cell-size);
  height: var(--rdp-cell-size);
  margin: 0;
  border: 2px solid transparent;
  border-radius: 100%;
}

.rdp-day_today:not(.rdp-day_outside) {
  font-weight: bold;
}

.rdp-day_selected,
.rdp-day_selected:focus-visible,
.rdp-day_selected:hover {
  color: white;
  opacity: 1;
  background-color: var(--rdp-accent-color);
}

.rdp-day_selected:focus-visible {
  /* Since the background is the same use again the outline */
  outline: var(--rdp-outline);
  outline-offset: 2px;
  z-index: 1;
}

.rdp:not([dir='rtl']) .rdp-day_range_start:not(.rdp-day_range_end) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.rdp:not([dir='rtl']) .rdp-day_range_end:not(.rdp-day_range_start) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.rdp[dir='rtl'] .rdp-day_range_start:not(.rdp-day_range_end) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.rdp[dir='rtl'] .rdp-day_range_end:not(.rdp-day_range_start) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.rdp-day_range_end.rdp-day_range_start {
  border-radius: 100%;
}

.rdp-day_range_middle {
  border-radius: 0;
}

.date-picker__wrapper{position:relative}.date-picker__popper{padding:16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);box-shadow:0 8px 24px rgba(0,0,0,.12)}.rdp{--rdp-accent-color: var(--button-bg);--rdp-background-color: rgba(var(--center-channel-color-rgb), 0.08);--rdp-cell-size: 36px;margin:0}.rdp .rdp-caption{padding:4px}.rdp .rdp-caption .rdp-caption_label{color:var(--center-channel-color);font-family:"Metropolis";font-size:16px;font-style:normal;font-weight:600;line-height:24px}.rdp .rdp-head_cell{color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans";font-size:12px;font-style:normal;font-weight:600;letter-spacing:.02em;line-height:16px;text-transform:uppercase}.rdp .rdp-cell{padding:4px}.rdp .rdp-button{font-weight:600}.rdp .rdp-button.rdp-day{color:var(--center-channel-color)}.rdp .rdp-button.rdp-day_selected{color:var(--button-color)}.rdp .rdp-button.rdp-day_selected:focus-visible:not([disabled]){background-color:var(--rdp-accent-color)}.rdp .rdp-button.rdp-day_selected:hover{background-color:var(--rdp-accent-color);color:var(--button-color)}.rdp .rdp-button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.rdp .rdp-button:active{background-color:rgba(var(--button-bg-rgb), 0.12);color:var(--button-bg)}.rdp .rdp-button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32);opacity:unset}.rdp .rdp-button[disabled]:hover{background-color:rgba(0,0,0,0)}.rdp .rdp-button.rdp-nav_button{border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75)}.rdp .rdp-button.rdp-nav_button_previous{margin-right:8px}.rdp .rdp-button.rdp-nav_button .icon{font-size:24px;font-weight:400;line-height:24px}.rdp .rdp-button.rdp-nav_button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.rdp .rdp-button.rdp-nav_button:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.rdp .rdp-button.rdp-nav_button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32)}.rdp .rdp-button.rdp-nav_button[disabled]:hover{background-color:rgba(0,0,0,0)}
.no-results__holder{display:grid;width:100%;height:100%;place-content:center}.no-results__wrapper{display:flex;max-width:500px;flex-direction:column;align-items:center;padding:30px;margin:auto;text-align:center;word-break:break-word}.no-results__wrapper.horizontal-layout{flex-direction:row}.no-results__wrapper.horizontal-layout svg{flex:0 0 auto;margin-right:16px}.no-results__wrapper.horizontal-layout .no-results__text-container{display:flex;flex-direction:column;text-align:start}.no-results__wrapper.horizontal-layout .no-results__title{margin-bottom:10px}.no-results__variant-wrapper{display:flex;align-items:center;justify-content:center;border-radius:100%;margin:22px}.no-results__title{margin:0;margin-bottom:15px;color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:20px}.no-results__subtitle{color:rgba(var(--center-channel-color-rgb), 0.72)}.no-results__icon{display:flex}.no-results__icon svg{fill:none}.no-results__icon.icon{color:var(--button-bg);font-size:62px}.no-results__mini_icon{width:11px;margin:2px;vertical-align:middle}.no-results__mini_icon svg{fill:var(--button-bg)}
.edit-category__helpText{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:40px}.GenericModal__button.delete{background:var(--dnd-indicator) !important}.delete-category__helpText{color:var(--center-channel-color)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}#userAccountMenu .userAccountMenu_nameMenuItem{align-items:center}#userAccountMenu .userAccountMenu_nameMenuItem .leading-element{width:unset;height:unset;margin-inline-end:12px}#userAccountMenu .userAccountMenu_nameMenuItem .label-elements{gap:0}#userAccountMenu .userAccountMenu_nameMenuItem span.userAccountMenu_nameMenuItem_primaryLabel{max-width:150px;margin:0;font-family:"Metropolis",sans-serif;font-size:16px;font-weight:600;line-height:22px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}#userAccountMenu .userAccountMenu_nameMenuItem span.userAccountMenu_nameMenuItem_secondaryLabel{max-width:150px;font-size:14px;line-height:18px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}#userAccountMenu .userAccountMenu_setCustomStatusMenuItem .userAccountMenu_setCustomStatusMenuItem_icon>svg{fill:rgba(var(--center-channel-color-rgb), 0.75)}#userAccountMenu .userAccountMenu_setCustomStatusMenuItem>.leading-element,#userAccountMenu .userAccountMenu_setCustomStatusMenuItem .userAccountMenu_setCustomStatusMenuItem_icon{display:flex;align-items:center}#userAccountMenu .userAccountMenu_setCustomStatusMenuItem .label-elements>span{color:rgba(var(--center-channel-color-rgb), 0.75)}#userAccountMenu .userAccountMenu_customStatusMenuItem.hasTrailingElement .label-elements>span{max-width:156px}#userAccountMenu .userAccountMenu_customStatusMenuItem .label-elements>span{max-width:196px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}#userAccountMenu .userAccountMenu_menuItemTrailingCheckIcon{color:var(--button-bg);font-size:16px}#userAccountMenu .userAccountMenu_menuItemTrailingIconClear{font-size:16px}#userAccountMenu .userAccountMenu_profileMenuItem_tourWrapper{position:absolute;top:0;right:0;bottom:0;left:0}.userAccountMenu_dndMenuItem_subMenuTitle{padding:6px 20px;margin:0;color:var(--center-channel-color);font-weight:bold;pointer-events:none}.userAccountMenu_menuButton{position:relative;display:flex;height:auto;align-items:center;align-self:center;padding:4px 8px;border:none;border-radius:4px;background:rgba(0,0,0,0);margin-inline-start:8px}.userAccountMenu_menuButton:hover,.userAccountMenu_menuButton[aria-expanded=true]{background:var(--sidebar-text-08)}.userAccountMenu_menuButton:hover .userStatusIconWrapper,.userAccountMenu_menuButton[aria-expanded=true] .userStatusIconWrapper{background-image:linear-gradient(0deg, rgba(var(--global-header-text-rgb), 0.08), rgba(var(--global-header-text-rgb), 0.08))}.userAccountMenu_menuButton.withCustomStatus{background:rgba(var(--global-header-text-rgb), 0.16)}.userAccountMenu_menuButton.withCustomStatus .userStatusIconWrapper{background-image:linear-gradient(0deg, rgba(var(--global-header-text-rgb), 0.16), rgba(var(--global-header-text-rgb), 0.16))}.userAccountMenu_menuButton .userStatusIconWrapper{position:absolute;top:auto;right:3px;bottom:1px;display:inline-flex;width:16px;height:16px;align-items:center;justify-content:center;border-radius:100px;margin:0;background-color:var(--global-header-background);color:var(--global-header-text);line-height:0;visibility:visible}.userAccountMenu_menuButton .userStatusIconWrapper:hover{cursor:pointer}.userAccountMenu_menuButton .userStatusIconWrapper svg{top:0}.userAccountMenu_onlineMenuItem_icon{color:var(--online-indicator)}.userAccountMenu_awayMenuItem_icon{color:var(--away-indicator)}.userAccountMenu_dndMenuItem_icon{color:var(--dnd-indicator)}.userAccountMenu_offlineMenuItem_icon{color:rgba(141,147,165,.56)}
.search-teams-selector-menu-button{display:flex;max-width:250px;align-items:center;padding:0 6px 0 8px;border:0;border-radius:var(--radius-s, 4px);background-color:rgba(0,0,0,0);font-size:12px;font-weight:600;line-height:24px}.search-teams-selector-menu-button:hover{background-color:var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.search-teams-selector-menu-button>span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.search-teams-selector-menu-button.search-teams-selector-menu-button__different-team,.search-teams-selector-menu-button[aria-expanded=true]{background:var(--button-bg-8, rgba(28, 88, 217, 0.08));color:var(--button-bg, #1c58d9)}.search-teams-selector-menu-button.search-teams-selector-menu-button__different-team:hover,.search-teams-selector-menu-button[aria-expanded=true]:hover{background-color:var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.search-teams-selector-current-team.MuiMenuItem-root{margin-bottom:8px}.select-team-mui-menu{min-width:220px}.select-team-mui-menu>.MuiMenuItem-root{justify-content:space-between !important}.select-team-mui-menu>.MuiMenuItem-root>.label-elements{overflow:hidden;flex-basis:auto !important;flex-grow:0 !important;flex-shrink:1 !important;text-overflow:ellipsis;white-space:nowrap}.select-team-mui-menu>.MuiMenuItem-root>.trailing-elements{margin-left:16px}
.GlobalSearchNav {
    display: flex;
    max-width: 432px;
    flex: 1;
    flex-direction: row;
    flex-wrap: nowrap;
    align-items: center;
    justify-content: initial;
    padding: 0;
    margin: 0;
}

.HeaderIconButton{display:flex;overflow:visible;width:auto;align-items:center;justify-content:center;padding:6px;border:none;border-radius:4px;margin:0;background:rgba(var(--bg-color), var(--bg-opacity));color:rgba(var(--text-color), var(--text-opacity));font:inherit;outline:none;text-align:inherit;--bg-color: var(--sidebar-header-text-color-rgb);--text-color: var(--sidebar-header-text-color-rgb)}.HeaderIconButton--toggled:not(:disabled){--text-color: var(--sidebar-header-bg-rgb)}.HeaderIconButton:not(:disabled){--bg-opacity: 0;--text-opacity: 0.56}.HeaderIconButton:not(:disabled):hover{--bg-opacity: 0.08;--text-opacity: 0.72}.HeaderIconButton:not(:disabled).HeaderIconButton--toggled{--bg-opacity: 1;--text-opacity: 1}.HeaderIconButton:not(:disabled).HeaderIconButton--toggled:hover{--bg-opacity: 0.92;--text-opacity: 1}.HeaderIconButton:not(:disabled).HeaderIconButton--active,.HeaderIconButton:not(:disabled):active{--bg-opacity: 0.16;--text-opacity: 1}.HeaderIconButton:disabled{cursor:no-allowed;--bg-opacity: 0;--text-opacity: 0.32}.HeaderIconButton:focus-visible{box-shadow:inset 0 0 0 2px hsla(0,0%,100%,.32),inset 0 0 0 2px var(--sidebar-header-bg)}.HeaderIconButton>i{position:relative;display:inline-flex;width:16px;height:16px;align-items:center;justify-content:center;padding:0;color:inherit}.HeaderIconButton>i::before{margin:0;font-size:18px;letter-spacing:18px;line-height:1}
.shortcut-line span:first-child{margin-right:5px}.shortcut-line .shortcut-key{padding:2px 5px}.shortcut-line .shortcut-key+.shortcut-key{margin-left:2px}.tooltip-inner .shortcut-line{margin:4px 0}@media(max-height: 800px){.shortcut-line{margin-top:14px}}
.modal .shortcuts-modal{width:1100px;margin-top:50px}.modal .shortcuts-modal .col-sm-4{padding-right:20px;padding-left:20px}.modal .shortcuts-modal .modal-header .shortcut-line{display:flex;align-items:center;margin:0}.modal .shortcuts-modal .modal-header .shortcut-line .shortcut-key{height:fit-content;flex:0 0 auto;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.modal .shortcuts-modal .modal-header .shortcut-line span:first-child{margin-right:12px}.modal .shortcuts-modal .modal-body{max-height:calc(100vh - 200px);padding:32px 28px}.modal .shortcuts-modal .section{margin-bottom:32px}.modal .shortcuts-modal .section .shortcut-line{display:flex;padding:10px 0;border-bottom:var(--border-light);gap:4px}.modal .shortcuts-modal .section .shortcut-line .shortcut-key{height:fit-content;flex:0 0 auto;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.modal .shortcuts-modal .section .shortcut-line span{flex-grow:1}.modal .shortcuts-modal .section-title{margin:0 0 12px;font-size:18px}.modal .shortcuts-modal .subsection{margin:12px 0 0 0}.modal .shortcuts-modal .subsection-title{padding-top:8px;font-size:inherit;font-weight:600;line-height:inherit}.modal .shortcuts-modal .info__label{margin:1rem 0;text-align:center}@media(max-height: 800px){.modal .shortcuts-modal .section-title{margin-top:0}.modal .shortcuts-modal .info__label{margin-top:0}}
.about-modal.cloud{position:absolute;top:50%;left:50%;margin:auto;transform:translate(-50%, -50%) !important}.about-modal.cloud .about-modal__hash{padding-bottom:20px}.about-modal.cloud .modal-content{overflow:hidden;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:8px;box-shadow:0 20px 32px rgba(0,0,0,.12)}.about-modal.cloud .modal-content .modal-header{width:600px;height:66px}.about-modal.cloud .modal-content .modal-body{overflow:hidden;width:600px;padding:0 50px}.about-modal.cloud .modal-content .modal-body .about-modal__logo{padding-right:32px;padding-left:0}.about-modal.cloud .modal-content .modal-body .about-modal__logo svg{width:104px;height:104px}.about-modal.cloud .modal-content .modal-body .about-modal__title{margin:0;font-size:24px;font-weight:600;line-height:32px}.about-modal.cloud .modal-content .modal-body .about-modal__content{padding-top:46px}.about-modal.cloud .modal-content .modal-body .subtitle{top:32px;left:0;width:294px;height:24px;margin-bottom:16px;color:var(--center-channel-color);font-size:16px;line-height:24px}.about-modal.cloud .modal-content .modal-body .description,.about-modal.cloud .modal-content .modal-body .form-group{top:0;left:0;width:342px;height:20px;align-self:center;margin:0 0;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:14px;line-height:20px}.about-modal.cloud .modal-content .modal-body .about-footer{margin-top:16px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.about-modal.cloud .modal-content .modal-body .about-footer .copy-right{margin-top:12px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.user-profile-popover-floating-overlay{z-index:1200}.user-profile-popover{width:240px;max-height:calc(100vh - 240px);border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);box-shadow:var(--elevation-4);overflow-x:hidden;overflow-y:auto}.user-profile-popover .user-profile-popover_container{display:flex;height:100%;flex-direction:column}.user-profile-popover .user-profile-popover-title{position:sticky;z-index:1;top:0;display:flex;flex-wrap:nowrap;align-items:center;justify-content:flex-start;justify-content:end;justify-content:space-between;padding:12px 8px 12px 8px;background:var(--center-channel-bg)}.user-profile-popover .user-profile-popover-title .user-popover__role{max-width:200px;flex-grow:1;background:unset;padding-inline-start:8px}.user-profile-popover .user-profile-popover-title .user-popover__role>span{height:16px;padding:0 4px;border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color-rgb);font-family:Open Sans,sans-serif;font-size:10px;letter-spacing:.2px;line-height:16px;text-transform:uppercase}.user-profile-popover .user-profile-popover-title .closeButtonRelativePosition{position:absolute;top:0;right:0;margin:8px 8px 0 0}.user-profile-popover .user-profile-popover-content .user-popover-image{position:relative;width:128px;margin:0 auto 8px auto}.user-profile-popover .user-profile-popover-content .user-popover-image #userAvatar{width:120px;min-width:120px;height:120px}.user-profile-popover .user-profile-popover-content .user-popover-image .user-popover-status{position:absolute;top:auto;right:8px;bottom:0;display:flex;width:24px;height:24px;padding:2px;border-radius:50px;background:rgba(var(--center-channel-bg-rgb), 1)}.user-profile-popover .user-profile-popover-content .user-popover-image .user-popover-status svg{width:100%;min-height:100%}.user-profile-popover .user-profile-popover-content .user-popover-last-active{display:block;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans";font-size:11px;font-weight:400;letter-spacing:.02em;line-height:16px;margin-block-end:8px;padding-inline-end:16px;padding-inline-start:16px;text-align:center}.user-profile-popover .user-profile-popover-content .user-profile-popover__heading{display:flex;flex-wrap:nowrap;align-items:center;justify-content:center;padding-inline-end:16px;padding-inline-start:16px;text-align:center}.user-profile-popover .user-profile-popover-content .user-profile-popover__heading>p{margin:0;font-family:Metropolis,sans-serif;font-size:20px;font-weight:600;line-height:28px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-profile-popover__heading i.shared-user-icon{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:16px}.user-profile-popover .user-profile-popover-content .user-profile-popover__non-heading{font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;margin-block-end:4px;padding-inline-end:16px;padding-inline-start:16px;text-align:center;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content hr{border-color:rgba(var(--center-channel-color-rgb), 0.08);margin-block-end:16px;margin-block-start:16px}.user-profile-popover .user-profile-popover-content hr.user-popover__bottom-row-hr{margin-block-start:4px}.user-profile-popover .user-profile-popover-content .user-profile-popover__email{display:flex;width:238px;align-items:center;padding:0 16px 10px 16px;justify-self:start}.user-profile-popover .user-profile-popover-content .user-profile-popover__email i.icon-email-outline{margin-inline-end:8px}.user-profile-popover .user-profile-popover-content .user-profile-popover__email i.icon-email-outline::before{margin-inline-end:0;margin-inline-start:0}.user-profile-popover .user-profile-popover-content .user-profile-popover__email a{font-family:"Open Sans";font-size:14px;font-weight:400;line-height:20px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-profile-popover-pluggables:not(:empty){padding:0 16px 12px 16px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-popover__custom-status{display:flex;align-items:center;font-family:"Open Sans";font-size:14px}.user-profile-popover .user-profile-popover-content .user-popover__custom-status span.emoticon{font-size:16px}.user-profile-popover .user-profile-popover-content .user-popover__custom_attributes{display:flex;flex-direction:column;padding:0 16px 12px 16px}.user-profile-popover .user-profile-popover-content .user-popover__custom_attributes .user-popover__subtitle{margin-bottom:4px;font-size:11px;font-weight:600;gap:4px;line-height:16px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-popover__custom_attributes .user-popover__subtitle-text{margin:0;overflow-wrap:break-word}.user-profile-popover .user-profile-popover-content .user-popover__time-status-container{display:flex;flex-direction:column;padding:0 16px 12px 16px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-popover__time-status-container .user-popover__subtitle{display:flex;margin-bottom:4px;font-size:11px;font-weight:600;gap:4px;line-height:16px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.user-profile-popover .user-profile-popover-content .user-popover__time-status-container .user-popover__subtitle-text{margin:0}.user-profile-popover .user-profile-popover-content .user-popover__time-status-container .user-popover__set-status{width:fit-content;height:auto;padding:4px 0 0;border:none;background:none}.user-profile-popover .user-profile-popover-bottom-row{position:sticky;bottom:0;background:var(--center-channel-bg)}.user-profile-popover .user-profile-popover-bottom-row .user-popover__bottom-row-container{display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:0 16px 16px 16px;margin:0;gap:4px;row-gap:8px}.user-profile-popover .user-profile-popover-bottom-row .user-popover__bottom-row-container .user-popover__bottom-row-end{display:flex;flex-wrap:wrap;align-items:center;gap:4px;justify-items:flex-end;row-gap:4px}
.user-groups-modal-create.modal-dialog,.user-groups-modal-update.modal-dialog,.view-user-groups-modal.modal-dialog,.user-groups-modal.modal-dialog{margin-top:50px}.user-groups-modal-create .modal-content,.user-groups-modal-update .modal-content,.view-user-groups-modal .modal-content,.user-groups-modal .modal-content{border-radius:8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner,.user-groups-modal .modal-content .ad_ldap_upsell_banner{position:sticky;z-index:4;right:12px;bottom:6px;left:12px;display:flex;height:44px;align-items:center;justify-content:space-between;padding:12px 8px;border-radius:8px;margin:0 12px;background-color:var(--sidebar-active-border);box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--button-color)}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .message,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .message,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .message,.user-groups-modal .modal-content .ad_ldap_upsell_banner .message{display:flex;gap:8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .btn-container,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .btn-container,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .btn-container,.user-groups-modal .modal-content .ad_ldap_upsell_banner .btn-container{display:flex;gap:13px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .banner-close,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .banner-close,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .banner-close,.user-groups-modal .modal-content .ad_ldap_upsell_banner .banner-close{height:4rem;border:none;margin-top:0;background:none;font-size:25px;font-weight:400;line-height:18px}.user-groups-modal-create .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.user-groups-modal-update .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.view-user-groups-modal .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn,.user-groups-modal .modal-content .ad_ldap_upsell_banner .ad-ldap-banner-btn{border:none;background:none;color:var(--button-color);font-size:14px;font-weight:600;line-height:14px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm,.user-groups-modal .modal-content .ad_ldap_upsell_confirm{position:sticky;z-index:4;top:0;right:0;bottom:0;left:0;overflow:hidden;width:100%;height:100%;border-radius:0 0 8px 8px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-backdrop{position:fixed;z-index:5;bottom:164px;width:100%;height:calc(100% - 164px);background:rgba(0,0,0,.16)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .upsell-confirm-foreground{height:148px;padding:16px 32px;background:var(--button-color)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .title,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .title,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .title,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .title{color:#000;font-size:14px;font-weight:600;line-height:20px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .subtitle,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .subtitle,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .subtitle,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .subtitle{color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container{display:flex;justify-content:right;gap:10px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .confrim-btn{width:100px;height:32px;padding:10px 16px;border:none;border-radius:4px;background:rgba(28,88,217,.08);color:var(--button-bg);font-size:12px;font-weight:600;line-height:10px}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .learn-more{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.user-groups-modal-create .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.user-groups-modal-update .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.view-user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .continue,.user-groups-modal .modal-content .ad_ldap_upsell_confirm .btns-container .continue{background:var(--button-bg);color:var(--button-color)}.user-groups-modal-create .modal-content .GenericModal__header,.user-groups-modal-update .modal-content .GenericModal__header,.view-user-groups-modal .modal-content .GenericModal__header,.user-groups-modal .modal-content .GenericModal__header{display:flex}.user-groups-modal-create .modal-body,.user-groups-modal-update .modal-body,.view-user-groups-modal .modal-body,.user-groups-modal .modal-body{max-height:100%;padding:0}.user-groups-modal-create .modal-body .no-results__wrapper,.user-groups-modal-update .modal-body .no-results__wrapper,.view-user-groups-modal .modal-body .no-results__wrapper,.user-groups-modal .modal-body .no-results__wrapper{max-width:350px;padding-bottom:60px}.user-groups-modal-create .modal-body .user-groups-search,.user-groups-modal-update .modal-body .user-groups-search,.view-user-groups-modal .modal-body .user-groups-search,.user-groups-modal .modal-body .user-groups-search{position:relative;margin:6px 32px 8px}.user-groups-modal-create .modal-body .user-groups-search .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-search .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-search .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-search .Input_container .Input_wrapper{margin:6px 0;line-height:38px}.user-groups-modal-create .modal-body .user-groups-search .Input_container .Input.form-control,.user-groups-modal-update .modal-body .user-groups-search .Input_container .Input.form-control,.view-user-groups-modal .modal-body .user-groups-search .Input_container .Input.form-control,.user-groups-modal .modal-body .user-groups-search .Input_container .Input.form-control{height:34px;border:none;font-size:14px;line-height:38px}.user-groups-modal-create .modal-body .user-groups-search .fa-search,.user-groups-modal-update .modal-body .user-groups-search .fa-search,.view-user-groups-modal .modal-body .user-groups-search .fa-search,.user-groups-modal .modal-body .user-groups-search .fa-search{position:absolute;top:15px;left:16px;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:16px;pointer-events:none}.user-groups-modal-create .modal-body .more-modal__dropdown,.user-groups-modal-update .modal-body .more-modal__dropdown,.view-user-groups-modal .modal-body .more-modal__dropdown,.user-groups-modal .modal-body .more-modal__dropdown{width:100%;padding:0 32px 24px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown{display:inline-flex;padding:6px;border:none;border-radius:4px;background:none;line-height:12px}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:hover,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:active,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown:active{background:rgba(var(--button-bg-rgb), 0.08)}.user-groups-modal-create .modal-body .more-modal__dropdown #groupsFilterDropdown span,.user-groups-modal-update .modal-body .more-modal__dropdown #groupsFilterDropdown span,.view-user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown span,.user-groups-modal .modal-body .more-modal__dropdown #groupsFilterDropdown span{color:var(--button-bg);font-size:12px;line-height:12px;white-space:nowrap}.user-groups-modal-create .modal-body .more-modal__dropdown .groups-filter-btn span,.user-groups-modal-update .modal-body .more-modal__dropdown .groups-filter-btn span,.view-user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span,.user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span{width:100%}.user-groups-modal-create .modal-body .more-modal__dropdown .groups-filter-btn span i,.user-groups-modal-update .modal-body .more-modal__dropdown .groups-filter-btn span i,.view-user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span i,.user-groups-modal .modal-body .more-modal__dropdown .groups-filter-btn span i{display:flex;align-items:center;margin-left:auto;color:var(--button-bg)}.user-groups-modal-create .modal-body .user-groups-modal__content,.user-groups-modal-update .modal-body .user-groups-modal__content,.view-user-groups-modal .modal-body .user-groups-modal__content,.user-groups-modal .modal-body .user-groups-modal__content{overflow:auto}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list{position:relative;max-height:460px;padding-top:24px;padding-bottom:16px;overflow-y:scroll;overflow-y:overlay}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar{width:20px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-track{background:rgba(0,0,0,0)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list::-webkit-scrollbar-thumb{border:8px rgba(0,0,0,0) solid;border-radius:9999px;background:rgba(var(--center-channel-color-rgb), 0.24);background-clip:padding-box}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row{display:flex;align-items:center;padding:14px 32px;border:none;background:none;line-height:38px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover{background:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:active,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:active{background:rgba(var(--button-bg-rgb), 0.08)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name{display:flex;overflow:hidden;max-width:200px;align-items:center;gap:8px;text-overflow:ellipsis;white-space:nowrap}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name svg,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name svg,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name svg,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name svg,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name svg,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name svg,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-display-name svg,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name svg{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-name{padding-left:8px;color:rgba(var(--center-channel-color-rgb), 0.75)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-member-count{margin-right:8px;margin-left:auto;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action{width:24px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper{width:24px;margin-left:auto}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .MenuWrapper .Menu{position:absolute;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin-top:8px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action .group-actions-menu span.MenuItem__primary-text{font-size:14px;line-height:20px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper{display:flex;width:24px;height:24px;flex-direction:column;align-items:center;padding:4px 6px;border:none;border-radius:4px;margin-left:auto;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);text-decoration:none}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:hover{border-radius:4px;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);fill:rgba(var(--center-channel-color-rgb), 0.8)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row .group-action button.action-wrapper i.icon{font-size:16px;line-height:16px}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .group-row:hover .group-action button.action-wrapper i{display:flex}.user-groups-modal-create .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.user-groups-modal-update .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.view-user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .loading-screen,.user-groups-modal .modal-body .user-groups-modal__content.user-groups-list .loading-screen{position:fixed;bottom:0;height:60px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper{padding:6px 32px 12px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container :focus,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container :focus{border-color:rgba(0,0,0,0);box-shadow:none;outline-style:none}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input_wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input_wrapper{margin:6px 0;line-height:38px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal-create .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal-update .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.view-user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper .Input_container .Input,.user-groups-modal .modal-body .user-groups-modal__content .group-name-input-wrapper .Input_container .Input{font-size:14px;line-height:38px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-mention-input-wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-mention-input-wrapper{padding:12px 32px 24px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-add-people-fieldset,.user-groups-modal-update .modal-body .user-groups-modal__content .group-add-people-fieldset,.view-user-groups-modal .modal-body .user-groups-modal__content .group-add-people-fieldset,.user-groups-modal .modal-body .user-groups-modal__content .group-add-people-fieldset{margin-top:20px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-add-people-fieldset legend,.user-groups-modal-update .modal-body .user-groups-modal__content .group-add-people-fieldset legend,.view-user-groups-modal .modal-body .user-groups-modal__content .group-add-people-fieldset legend,.user-groups-modal .modal-body .user-groups-modal__content .group-add-people-fieldset legend{padding:0 32px;border:none;margin-bottom:10px;color:inherit;font-family:Metropolis,sans-serif;font-size:18px;font-weight:600;line-height:24px}.user-groups-modal-create .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.user-groups-modal-update .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.view-user-groups-modal .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper,.user-groups-modal .modal-body .user-groups-modal__content .group-add-user .multi-select__wrapper{margin-top:0}
.user-groups-modal-create.modal-dialog{margin-top:calc(50vh - 240px)}.user-groups-modal-create .modal-body{overflow:visible}.user-groups-modal-create .Input___error.group-error{position:absolute;bottom:35px;left:24px}
.user-groups-modal-update .modal-body .update-buttons-wrapper{display:flex;align-items:center;padding:0 24px 24px;float:right}.user-groups-modal-update .modal-body .update-buttons-wrapper .Input___error{margin-top:0;margin-right:12px}.user-groups-modal-update .modal-body .update-buttons-wrapper button{height:40px;padding:0 20px;border-radius:4px;font-size:14px;font-weight:600}.user-groups-modal-update .modal-body .update-buttons-wrapper button[disabled]{color:rgba(var(--center-channel-color-rgb), 0.32)}
.view-user-groups-modal .modal-content .modal-header{overflow:visible;padding-top:0;padding-bottom:0}.view-user-groups-modal .modal-content .modal-header .modal-title{display:flex;align-items:center;margin-left:16px;gap:4px}.view-user-groups-modal .modal-content .modal-header .modal-title i,.view-user-groups-modal .modal-content .modal-header .modal-title svg{margin-left:5px;color:rgba(var(--center-channel-color-rgb), 0.64)}.view-user-groups-modal .modal-content .modal-header .details-action .MenuWrapper{margin-left:auto}.view-user-groups-modal .modal-body{overflow:visible}.view-user-groups-modal .modal-body .no-results__wrapper{padding-bottom:60px}.view-user-groups-modal .modal-body .group-mention-name{margin:-24px 0 24px 6px}.view-user-groups-modal .modal-body .group-mention-name span.group-name{margin-left:70px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:12px}.view-user-groups-modal .modal-body .group-mention-name span.group-source span{padding:0 4px;border-radius:4px;margin-left:8px;background:rgba(var(--center-channel-color-rgb), 0.08);font-size:10px;line-height:16px}.view-user-groups-modal .modal-body .user-groups-search{margin-bottom:24px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list{max-height:450px;padding-bottom:16px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);overflow-y:scroll;overflow-y:overlay}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar{width:20px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar-track{background:rgba(0,0,0,0)}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list::-webkit-scrollbar-thumb{border:8px rgba(0,0,0,0) solid;border-radius:9999px;background:rgba(var(--center-channel-color-rgb), 0.24);background-clip:padding-box}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-count{padding:0 32px;margin:12px 0 8px 0;font-family:inherit;font-size:inherit;font-weight:600;line-height:inherit}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row{display:flex;align-items:center;padding:8px 32px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row .group-member-name{padding-left:12px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row .group-member-username{padding-left:6px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:18px}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row button.remove-group-member{margin-right:0;margin-left:auto;opacity:0}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:hover,.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:focus-within{background:rgba(var(--center-channel-color-rgb), 0.08)}.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:hover button.remove-group-member,.view-user-groups-modal .modal-body .user-groups-modal__content.group-member-list .group-member-row:focus-within button.remove-group-member{opacity:1}
#user-group-popover .popover-content{padding:0}.user-group-popover-floating-overlay{z-index:1150}
.NotificationFromMembersModal .modal-content .modal-header .close{top:16px !important;right:15px !important}.NotificationFromMembersModal .modal-content .modal-body .GenericModal__header{padding:6px 24px 16px 24px}
.inline-entity-link{display:inline-flex;width:22px;height:22px;align-items:center;justify-content:center;padding:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);border-radius:50%;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.64) !important;cursor:pointer;line-height:1;text-decoration:none}.inline-entity-link:hover{background:rgba(var(--center-channel-color-rgb), 0.16);color:rgba(var(--center-channel-color-rgb), 0.72) !important;text-decoration:none}
.markdown-image-expand{position:relative;display:flex;align-items:center}.markdown-image-expand__collapse-button{position:absolute;top:0;left:0;display:none;width:24px;height:24px;padding:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:16px;background-color:var(--center-channel-bg);box-shadow:var(--elevation-1);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:18px;line-height:21px}.markdown-image-expand__collapse-button .icon{width:18px;height:18px}.markdown-image-expand--expanded:hover .markdown-image-expand__collapse-button{display:block}.markdown-image-expand__collapse-button:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.24);box-shadow:var(--elevation-2)}.markdown-image-expand__expand-button{display:inline-flex;width:100%;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.64);font-size:18px;line-height:18px}.markdown-image-expand__expand-button:hover{color:rgba(var(--center-channel-color-rgb), 0.8)}.markdown-image-expand__expand-button .icon{width:18px;height:18px}.markdown-image-expand__expand-button .icon::before{margin-right:0;margin-left:0}.markdown-image-expand__expand-icon{display:inline-block;vertical-align:middle}.markdown-image-expand__alt-text{display:inline-block;overflow:hidden;font-size:12px;line-height:16px;text-align:left;text-overflow:ellipsis;white-space:nowrap}
.plugin-link-tooltip-floating-overlay{z-index:1200}.plugin-link-tooltip-floating-overlay>*{pointer-events:auto}.plugin-link-tooltip-container{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);box-shadow:var(--elevation-4)}.plugin-link-tooltip-container .plugin-link-tooltip-arrow{fill:var(--center-channel-bg)}
.apps-form-modal-body-common{position:absolute;z-index:0;top:0;right:0;bottom:0;left:0;display:flex;align-items:center;justify-content:center;backdrop-filter:blur(0);background:var(--center-channel-bg)}.apps-form-modal-body-loaded{z-index:-10}.apps-form-modal-body-loading{z-index:1000}.apps-form-select-option .select-option-item{display:flex;flex-direction:row;align-items:center;column-gap:1.2rem}.apps-form-select-option .select-option-item-label{overflow:hidden;max-width:89%;text-overflow:ellipsis;white-space:nowrap}.apps-form-select-option .select-option-item-label .select-option-main{overflow:hidden;max-width:89%;text-overflow:ellipsis;white-space:nowrap}.apps-form-select-option .select-option-icon{display:inline-flex;flex:0 0 1.6rem;align-items:center;justify-content:center;fill:v(center-channel-color);opacity:.73}.apps-form-select-option .select-option-icon--large{width:2.4rem;height:2.4rem;flex:0 0 1.2rem;font-size:2rem}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.marketplace-modal{width:832px}.marketplace-modal.streamlined-marketplace .modal-header{padding:26px 32px 26px !important}.marketplace-modal.streamlined-marketplace.with-web-marketplace-link .modal-content{border-bottom-left-radius:16px !important;border-bottom-right-radius:16px !important}.marketplace-modal div.navigation-row{overflow:unset;margin-top:10px}.marketplace-modal div.navigation-row div{font-size:14px;text-align:center}.marketplace-modal div.navigation-row div button{font-size:14px;font-weight:bold}.marketplace-modal div.navigation-row div.count{padding:9px 15px}.marketplace-modal .input-clear{top:32px;right:36px;display:flex;width:32px;height:32px;align-items:center;justify-content:center;font-size:16px}.marketplace-modal .nav-tabs{padding:0 32px;margin:0 0 8px}.marketplace-modal .nav-tabs li{margin-right:0}.marketplace-modal .nav-tabs li a{padding:13px 12px;border:none;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:14px;font-weight:600;line-height:20px;transition:all .15s ease}.marketplace-modal .nav-tabs li a:hover,.marketplace-modal .nav-tabs li a:active,.marketplace-modal .nav-tabs li a:focus,.marketplace-modal .nav-tabs li a:focus-within{border:none;border-radius:none;background:rgba(0,0,0,0);color:var(--center-channel-color)}.marketplace-modal .nav-tabs li.active{border-bottom:2px solid var(--button-bg)}.marketplace-modal .nav-tabs li.active a{color:var(--button-bg)}.marketplace-modal .nav-tabs li:not(:first-child){margin-left:8px}.marketplace-modal h2{font-weight:300}.marketplace-modal h2 strong{font-weight:400}.marketplace-modal .more-modal__list{height:390px;margin:0 6px 8px 12px;overflow-y:scroll}.marketplace-modal .more-modal__list .more-modal__row{overflow:hidden;min-height:80px;padding:16px 20px;border-bottom:none}.marketplace-modal .more-modal__list .more-modal__row .marketplace__tag{margin-left:6px}.marketplace-modal .more-modal__list .more-modal__row .update{font-size:.9em}.marketplace-modal .more-modal__list .more-modal__row .update a{text-decoration:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details{padding-left:16px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details .more-modal__row--link{color:var(--center-channel-color);font-size:16px;font-weight:600;line-height:24px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__details .more-modal__description{margin:2px 0 0;color:var(--center-channel-color-rgb);font-size:14px;font-weight:400;line-height:20px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions{padding-left:16px;margin:0}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed{position:relative;display:inline-flex;align-items:center;justify-content:center;border:1px solid var(--button-bg);border-radius:4px;background:var(--center-channel-bg);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:hover{background:rgba(var(--button-bg-rgb), 0.08)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:active,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:active{background:rgba(var(--button-bg-rgb), 0.16)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:focus,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure:disabled,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed:disabled{border:rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-configure i,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-installed i{display:flex;font-size:18px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:active,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:focus,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install:disabled:not(.always-show-enabled),.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .plugin-install i,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions .app-install i{display:flex;font-size:18px}.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions a:hover,.marketplace-modal .more-modal__list .more-modal__row .more-modal__actions a:focus{text-decoration:none}.marketplace-modal .more-modal__list .more-modal__row:hover,.marketplace-modal .more-modal__list .more-modal__row:focus,.marketplace-modal .more-modal__list .more-modal__row:focus-within{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.marketplace-modal .more-modal__list .icon__plugin{display:flex;height:48px;flex:0 0 48px;align-items:center;justify-content:center;border-radius:50%;background-color:#fff}.marketplace-modal .more-modal__list .icon__plugin svg,.marketplace-modal .more-modal__list .icon__plugin img{width:48px;height:48px}.marketplace-modal .more-modal__list .icon__plugin svg{fill:var(--button-bg)}.marketplace-modal .more-modal__list .icon__plugin img{border-radius:4px}.marketplace-modal .marketplace-modal-search{padding:24px 0 0}.marketplace-modal .marketplace-modal-search .search_input{width:100%;border:0 !important;border-radius:0 !important;box-shadow:none}.marketplace-modal .btn{min-width:8rem;padding:8px 16px;border-radius:4px;font-size:13px;font-weight:600}.marketplace-modal .btn-outline{border:1px solid var(--button-bg);background:rgba(0,0,0,0)}.marketplace-modal .tabs{display:flex;width:100%;flex-direction:column;margin-top:12px}.marketplace-modal .tabs .nav-tabs{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.marketplace-modal .subtitle{margin-left:5px}.marketplace-modal .plugin__list{display:flex;flex-direction:column}.marketplace-modal .plugin__list .plugin__row{display:flex;align-items:center;padding:10px 15px;border-bottom:1px solid rgba(0,0,0,.15)}.marketplace-modal .plugin__list .plugin__row.clickable{cursor:pointer}.marketplace-modal .plugin__list .plugin__row:hover .plugin__actions--round{opacity:.5}.marketplace-modal .no_plugins{display:flex;height:390px;flex-flow:column;align-items:center;justify-content:center;margin-bottom:8px}.marketplace-modal .no_plugins__message{margin-top:20px;color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:28px}.marketplace-modal .no_plugins__action{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px;margin-top:30px}.marketplace-modal .no_plugins__action:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.marketplace-modal .no_plugins__action:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.marketplace-modal .no_plugins__action:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.marketplace-modal .no_plugins__action:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.marketplace-modal .no_plugins__action i{display:flex;font-size:18px}.marketplace-modal .no_plugins .icon__plugin svg{fill:var(--button-bg)}.marketplace-modal .item_error{background-color:rgba(var(--error-text-color-rgb), 0.08)}.marketplace-modal .loading{height:390px}.more-modal__description-tooltip .tooltip-inner{text-align:left}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.FeatureRestrictedModal__description{color:var(--center-channel-color);font-size:14px;font-weight:400;line-height:20px}.FeatureRestrictedModal__terms{padding-top:14px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:400;line-height:16px}.FeatureRestrictedModal__terms a{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px}.FeatureRestrictedModal__terms a:hover,.FeatureRestrictedModal__terms a:active,.FeatureRestrictedModal__terms a:focus{text-decoration-line:underline}.FeatureRestrictedModal__terms a:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.FeatureRestrictedModal__buttons{display:flex;justify-content:space-between;padding:24px 0}.FeatureRestrictedModal__buttons .button-plans{display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.FeatureRestrictedModal__buttons .button-plans:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.FeatureRestrictedModal__buttons .button-plans:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.FeatureRestrictedModal__buttons .button-plans:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.FeatureRestrictedModal__buttons .button-plans i{display:flex;font-size:18px}.FeatureRestrictedModal__buttons .button-plans i:first-child::before{margin:0 7px 0 0}.FeatureRestrictedModal__buttons .button-plans i:last-child::before{margin:0 0 0 7px}.FeatureRestrictedModal__buttons .button-trial{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.FeatureRestrictedModal__buttons .button-trial:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.FeatureRestrictedModal__buttons .button-trial:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.FeatureRestrictedModal__buttons .button-trial:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.FeatureRestrictedModal__buttons .button-trial:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.FeatureRestrictedModal__buttons .button-trial i{display:flex;font-size:18px}.FeatureRestrictedModal__buttons.single{justify-content:flex-end}.FeatureRestrictedModal__buttons.single .button-plans{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out}.FeatureRestrictedModal__buttons.single .button-plans:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.FeatureRestrictedModal__buttons.single .button-plans:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.FeatureRestrictedModal__buttons.single .button-plans:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.FeatureRestrictedModal__buttons.single .button-plans:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.FeatureRestrictedModal__buttons.single .button-plans i{display:flex;font-size:18px}
.RestrictedIndicator__icon-tooltip-container{display:flex;flex:1;align-items:center;align-self:stretch;padding:0 10px}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__button{padding:0}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__icon-tooltip{padding:5px 0;color:var(--button-bg);line-height:22px}.RestrictedIndicator__icon-tooltip-container .RestrictedIndicator__icon-tooltip.trial::before{content:"⚡"}a:focus+.RestrictedIndicator__icon-tooltip-container,a:hover+.RestrictedIndicator__icon-tooltip-container,button:focus+.RestrictedIndicator__icon-tooltip-container,button:hover+.RestrictedIndicator__icon-tooltip-container{background-color:rgba(var(--center-channel-color-rgb), 0.1)}.RestrictedIndicator__icon-tooltip{max-width:240px;align-items:center}.RestrictedIndicator__icon-tooltip .title{display:block;line-height:15px}.RestrictedIndicator__icon-tooltip .message{font-size:11px;letter-spacing:.02em;line-height:16px;opacity:.73}
#systemConsole{position:relative}.system-console-visit{position:absolute;top:0;right:0;bottom:0;left:0}
.announcementBarTooltip{min-width:50vw;max-width:90vw;pointer-events:auto}
.annnouncementBar__purchaseNow{display:block;margin-top:15px}
.annnouncementBar__renewLicense{display:block;margin-left:8px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.overage_users_banner__description{color:var(--center-channel-text);font-size:14px;font-weight:400;line-height:20px}.overage_users_banner__button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;background:rgba(0,0,0,0);font-size:14px}.overage_users_banner__button:hover,.overage_users_banner__button:active,.overage_users_banner__button:focus{text-decoration-line:underline}.overage_users_banner__button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}
.post-history-limit-banner{background-color:var(--yellow-400);color:var(--neutral-900)}.post-history-limit-banner .announcement-bar__text .btn.btn-tertiary.btn-xs.btn-inverted{border-color:var(--neutral-900);color:var(--neutral-900)}.post-history-limit-banner .announcement-bar__close{color:var(--neutral-900)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.three-days-left-generic-modal{margin-top:calc(40vh - 240px) !important}.ThreeDaysLeftTrialModal .modal-content,.ThreeDaysLeftTrialModal .modal-header{border-radius:8px}.ThreeDaysLeftTrialModal .modal-body{display:flex;overflow:hidden;width:100%;flex-direction:column;padding-bottom:24px !important}.ThreeDaysLeftTrialModal .modal-body .header-subtitle-text{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:400;line-height:16px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper{display:flex;flex-direction:column;margin-right:24px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card{display:flex;width:100%;height:136px;align-items:flex-start;padding:28px 0 16px;gap:10px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card .svg-wrapper{width:130px;height:91px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card .content-wrapper{display:flex;flex-direction:column;margin-left:15px;font-family:"Open Sans";font-style:normal}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card .content-wrapper .title{color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card .content-wrapper .description{margin-top:8px;font-size:14px;font-weight:400;line-height:20px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .three-days-left-card .content-wrapper .LearnMoreActionButton{margin-left:5px}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .workspace-limits-panel{margin:24px 0}.ThreeDaysLeftTrialModal .modal-body .main-wrapper .workspace-limits-panel .limits-title{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:10px;font-weight:700;letter-spacing:.02em;line-height:16px;text-transform:uppercase}.ThreeDaysLeftTrialModal .modal-body .divisory-line{width:598px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.1);margin-left:-32px}.ThreeDaysLeftTrialModal .modal-body .footer-content{display:flex;min-height:60px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn{align-self:self-end;margin-top:24px;margin-left:auto;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:40px;padding:0 20px;font-size:14px;line-height:14px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn i{display:flex;font-size:18px}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus-visible{outline:none !important}.ThreeDaysLeftTrialModal .modal-body .footer-content .open-view-plans-modal-btn:focus{border:0}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.header-footer-route{position:relative;display:flex;overflow:hidden;width:100%;min-height:100%;flex-direction:column;margin:0 auto;grid-area:main}.header-footer-route .header-footer-route-container{display:flex;width:100%;height:100vh;flex-flow:column;background-image:url(/static/files/c923d95df8d295625fd5.jpg);background-position:center;background-repeat:no-repeat;background-size:cover;-webkit-overflow-scrolling:touch;overflow-y:auto}
.cloud-preview-modal-fab{position:fixed;z-index:999;bottom:16px;left:16px}.cloud-preview-modal-fab__button{display:flex;width:36px;height:36px;align-items:center;justify-content:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;background-color:var(--center-channel-bg);box-shadow:0px 8px 24px 0px rgba(0,0,0,.16);cursor:pointer}.cloud-preview-modal-fab__button:active{box-shadow:0px 4px 16px 0px rgba(0,0,0,.12)}.cloud-preview-modal-fab__button:focus{box-shadow:0px 8px 24px 0px rgba(0,0,0,.16),0 0 0 2px var(--button-bg);outline:none}.cloud-preview-modal-fab__button .icon{color:rgba(var(--center-channel-color-rgb), 0.72);font-size:24px}#calls-expanded-view~.cloud-preview-modal-fab,.cloud-preview-modal-fab:has(~#calls-expanded-view){display:none}
.PreparingWorkspaceDescription{margin-bottom:24px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:18px}@media screen and (max-width: 900px){.PreparingWorkspaceDescription{font-size:16px}}
.PreparingWorkspaceTitle{display:flex;margin-top:0;margin-bottom:12px;color:var(--indigo-400);font-size:56px;letter-spacing:-0.01em}.PreparingWorkspaceTitle .subtitle{font-size:18px;line-height:28px}.PreparingWorkspaceTitle svg{margin:0 10px 0 20px}@media screen and (max-width: 900px){.PreparingWorkspaceTitle{flex-direction:column;font-size:36px}.PreparingWorkspaceTitle .subtitle{font-size:14px;line-height:20px}}
.LaunchingWorkspaceFullscreenWrapper-body{position:fixed;top:0;right:0;bottom:0;left:0;display:flex;align-items:center;justify-content:center;background-image:url(/static/files/c923d95df8d295625fd5.jpg);background-position:50%;background-repeat:no-repeat;background-size:cover;text-align:center}.LaunchingWorkspaceFullscreenWrapper-exit{opacity:1}.LaunchingWorkspaceFullscreenWrapper-exit-active{opacity:0;transition:opacity 500ms ease-in-out}.LaunchingWorkspaceFullscreenWrapper-edit-done{opacity:0}.LaunchingWorkspaceFullscreenWrapper__logo{position:absolute;z-index:1;top:32px;right:32px}.LaunchingWorkspace-body{display:flex;width:420px;height:100vh;flex-direction:column;align-items:center;justify-content:center;margin:auto;text-align:center}.LaunchingWorkspace-body--non-fullscreen{position:fixed;left:calc(50vw - 210px)}.LaunchingWorkspace__spinner{width:32px;margin-bottom:16px}.LaunchingWorkspace--enter-from-before-enter{opacity:0}.LaunchingWorkspace--enter-from-before-enter-active{opacity:1;transition:opacity 300ms ease-in-out}.LaunchingWorkspace--enter-from-before-enter-done{opacity:1}.LaunchingWorkspace--exit-to-before-exit{opacity:1}.LaunchingWorkspace--exit-to-before-exit-active{opacity:0;transition:opacity 300ms ease-in-out}.LaunchingWorkspace--exit-to-before-exit-done{opacity:0}
.PanelHeader{display:flex;min-height:40px;flex-wrap:nowrap;align-items:center;justify-content:space-between;padding:0 16px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.PanelHeader__right{display:inline-flex;flex-shrink:0;flex-wrap:nowrap;align-items:center;justify-content:flex-end}.PanelHeader__right div+div{padding-left:4px}.PanelHeader__left{display:flex;overflow:hidden;flex-wrap:nowrap;align-items:center;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.PanelHeader__left>span{display:inline-flex;min-width:0;align-items:center}.PanelHeader__left>span span{overflow:hidden;min-width:0;text-overflow:ellipsis;white-space:nowrap}.PanelHeader__timestamp{padding-right:8px;color:rgba(var(--center-channel-color-rgb), 0.75);vertical-align:middle}.PanelHeader__sync-icon{display:flex;align-items:center}.PanelHeader__actions{display:inline-flex;opacity:0}.PanelHeader__info{display:inline-flex;align-items:center}
.ScheduledPostIndicator{display:flex;flex-wrap:wrap;align-items:end;padding:8px 24px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;gap:5px}.ScheduledPostIndicator i.icon{width:16px;height:16px;font-size:16px}
.postBoxIndicator{display:flex;flex-direction:row;flex-wrap:wrap;gap:8px;padding-inline:24px}.postBoxIndicator:has(div){padding-block:8px}.postBoxIndicator div{padding:0}.postBoxIndicator span,.postBoxIndicator a{text-wrap:nowrap}.postBoxIndicator .userDisplayName{position:relative;top:4px;display:inline-block;overflow:hidden;max-width:350px;text-overflow:ellipsis;text-wrap:nowrap}
.AutoHeight{display:block}.AutoHeight>div{display:block}
.sectionNoticeContainer{position:relative;border-width:1px;border-style:solid;border-radius:4px}.sectionNoticeContainer p{margin:0}.sectionNoticeContainer.info,.sectionNoticeContainer.hint{border-color:rgba(var(--sidebar-text-active-border-rgb), 0.16);background:rgba(var(--sidebar-text-active-border-rgb), 0.08)}.sectionNoticeContainer.info p,.sectionNoticeContainer.hint p{color:var(--center-channel-color)}.sectionNoticeContainer.success{border-color:rgba(var(--online-indicator-rgb), 0.16);background:rgba(var(--online-indicator-rgb), 0.08)}.sectionNoticeContainer.success p{color:var(--center-channel-color)}.sectionNoticeContainer.danger{border-color:rgba(var(--dnd-indicator-rgb), 0.16);background:rgba(var(--dnd-indicator-rgb), 0.08)}.sectionNoticeContainer.danger p{color:var(--center-channel-color)}.sectionNoticeContainer.welcome{border-color:rgba(var(--center-channel-color-rgb), 0.08);background:rgba(var(--center-channel-color-rgb), 0.04)}.sectionNoticeContainer.welcome p{color:rgba(var(--center-channel-color-rgb), 0.72)}.sectionNoticeContainer.warning{border-color:rgba(var(--away-indicator-rgb), 0.16);background:rgba(var(--away-indicator-rgb), 0.08)}.sectionNoticeContainer.warning p{color:var(--center-channel-color)}.sectionNoticeActions{display:flex;flex-flow:wrap}.sectionNoticeClose{position:absolute;top:10px;right:10px}.sectionNoticeContent{display:flex;flex-direction:row;align-items:start;padding:16px;gap:12px}.sectionNoticeIcon{font-size:24px}.sectionNoticeIcon.info,.sectionNoticeIcon.hint{color:var(--sidebar-text-active-border)}.sectionNoticeIcon.success{color:var(--online-indicator)}.sectionNoticeIcon.danger{color:var(--dnd-indicator)}.sectionNoticeIcon.warning{color:var(--away-indicator)}.sectionNoticeTitle{margin:0;color:var(--center-channel-color);font-family:"Open Sans";font-size:14px;font-weight:600;line-height:24px}.sectionNoticeTitle.welcome{font-family:"Metropolis";font-size:20px;line-height:28px}.sectionNoticeTitle.noText{margin-bottom:0}.sectionNoticeBody{display:flex;flex-direction:column;gap:8px}.sectionNoticeButton{margin-top:4px;margin-bottom:4px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.file-overlay{position:absolute;z-index:13;top:0;left:0;width:100%;height:100%;color:#fff;font-size:1.4285714286em;font-weight:600;pointer-events:none;text-align:center}.file-overlay .overlay__indent{overflow:hidden;background-color:rgba(0,0,0,.75);position:relative;display:flex;height:100%;align-items:center;justify-content:center}.file-overlay.right-file-overlay{font-size:1.2857142857em}.file-overlay.right-file-overlay .overlay__files{width:150px}.file-overlay .overlay__circle{display:flex;width:300px;height:300px;max-height:100%;flex-direction:column;flex-wrap:wrap;align-items:center;justify-content:center;gap:20px;pointer-events:none}.file-overlay .overlay__circle.horizontal{width:max-content;flex-direction:row}.file-overlay .overlay__circle.horizontal .overlay__files{width:auto;height:96px;max-height:80%}.file-overlay .overlay__circle.horizontal span{display:flex;align-items:center}.file-overlay .overlay__files{display:block;width:128px}.file-overlay .overlay__logo{position:absolute;bottom:30px;left:50%;width:100px;margin-left:-50px;opacity:.3}.file-overlay .fa{display:inline-block;margin-right:8px;font-size:1.1em}
.DataSpillageAction{display:flex;gap:4px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.AdvancedTextbox{position:relative}.AdvancedTextbox__wrapper{position:relative;display:flex;flex-direction:column}.AdvancedTextbox__label{position:absolute;z-index:1;top:-6px;left:12px;display:flex;width:auto;padding:0 4px;border:none;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:10px;line-height:14px;opacity:0;transform:translateY(8px);transition-duration:.15s;transition-property:opacity,transform,color;transition-timing-function:ease-in-out;white-space:nowrap}.AdvancedTextbox__label--active{opacity:1;transform:translateY(0)}.AdvancedTextbox__label--focused{color:var(--button-bg)}.AdvancedTextbox__label--error{color:var(--error-text)}.AdvancedTextbox__label--focused.AdvancedTextbox__label--error{color:var(--error-text)}.AdvancedTextbox .textarea-wrapper{position:relative;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px}.AdvancedTextbox .textarea-wrapper:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.AdvancedTextbox .textarea-wrapper:focus-within{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.AdvancedTextbox .textarea-wrapper.textarea-wrapper-preview--disabled{cursor:not-allowed;opacity:.6}.AdvancedTextbox .textarea-wrapper.textarea-wrapper-preview--disabled:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.AdvancedTextbox .textarea-wrapper .textarea--has-errors{border-color:var(--error-text) !important}.AdvancedTextbox .textarea-wrapper .textarea--has-errors:focus{border-color:var(--error-text) !important;box-shadow:0 0 0 1px var(--error-text) !important}.AdvancedTextbox .textarea-wrapper .custom-textarea{border:none;box-shadow:none}.AdvancedTextbox .textarea-wrapper .custom-textarea.textbox-preview-area{overflow-y:auto}.AdvancedTextbox .textarea-wrapper .custom-textarea:focus{box-shadow:none}.AdvancedTextbox__error-wrapper{display:flex}.AdvancedTextbox__error-message{display:flex;width:90%;align-items:center;margin-top:4px;color:var(--error-text);font-size:12px}.AdvancedTextbox__error-message i{margin-right:4px;font-size:14px}.AdvancedTextbox__character-count{margin-top:4px;margin-left:auto;font-size:12px}.AdvancedTextbox__character-count.exceeds-limit{color:var(--error-text)}.AdvancedTextbox__character-count.below-minimum{color:var(--error-text)}.AdvancedTextbox__description{display:flex;align-items:center;padding:0;margin-top:4px;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}
.KeepRemoveFlaggedMessageConfirmationModal .modal-content{width:704px}.KeepRemoveFlaggedMessageConfirmationModal .body{display:flex;flex-direction:column;gap:24px}.KeepRemoveFlaggedMessageConfirmationModal .body .section.comment_section{display:flex;flex-direction:column;gap:8px}.KeepRemoveFlaggedMessageConfirmationModal .body .section .section_title{color:var(--center-channel-color);font-size:14px;font-weight:600}.KeepRemoveFlaggedMessageConfirmationModal .body button#PreviewInputTextButton{position:absolute;z-index:2;top:8px;right:8px}.KeepRemoveFlaggedMessageConfirmationModal .body textarea#RemoveFlaggedMessageConfirmationModal__comment{min-height:90px !important;max-height:400px}.KeepRemoveFlaggedMessageConfirmationModal .body .request_error{display:flex;width:90%;align-items:center;color:var(--error-text);font-size:12px}
.ChannelPropertyRenderer{display:flex;flex-direction:row;gap:8px}
.truncate,.PostAttachmentOpenGraph__body .description,.PostAttachmentOpenGraph__body .sitename,.PostAttachmentOpenGraph__body .title{display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;hyphens:auto;-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text}.PostAttachmentOpenGraph{position:relative;display:grid;width:100%;max-width:700px;padding:16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:5px 0;background-color:var(--center-channel-bg);box-shadow:0 2px 3px rgba(0,0,0,.08);grid-auto-columns:80px;grid-template-columns:1fr;text-decoration:none !important;transition:box-shadow}.PostAttachmentOpenGraph:hover:not(:active){border-color:rgba(var(--center-channel-color-rgb), 0.24);box-shadow:0 4px 6px rgba(0,0,0,.12)}.PostAttachmentOpenGraph:hover .remove-button{display:block}.PostAttachmentOpenGraph:active{border-color:rgba(var(--button-bg-rgb), 0.32)}.PostAttachmentOpenGraph .remove-button{position:absolute;z-index:10;top:-1px;left:-28px;display:none;padding:5px;border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0);color:rgba(var(--center-channel-color-rgb), 0.75)}.PostAttachmentOpenGraph .remove-button:hover:not(:active){background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8)}.PostAttachmentOpenGraph .remove-button:active{background-color:rgba(var(--button-bg-rgb), 0.16);color:rgba(var(--button-bg-rgb), 1)}.PostAttachmentOpenGraph__body .sitename,.PostAttachmentOpenGraph__body .title{-webkit-line-clamp:1;word-break:break-all}.PostAttachmentOpenGraph__body .sitename{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px;font-weight:400;line-height:16px}.PostAttachmentOpenGraph__body .title{margin-bottom:4px;color:var(--link-color);font-size:14px;font-weight:600;line-height:20px}.PostAttachmentOpenGraph__body .description{color:var(--center-channel-color);font-size:14px;font-weight:400;-webkit-line-clamp:2;line-height:20px;word-break:none}.PostAttachmentOpenGraph__body .isInPermalink{overflow:hidden;width:100%;height:1.5em;line-height:1.5em;text-overflow:ellipsis;white-space:nowrap}.PostAttachmentOpenGraph__image{position:relative;display:flex;overflow:visible;height:80px;border-radius:4px;grid-column:2/3;grid-row:1/2;place-content:stretch;place-items:stretch}.PostAttachmentOpenGraph__image.large{width:auto;max-width:392px;height:auto;max-height:240px;margin-top:12px;grid-column:1/2;grid-row:2/3;place-content:center;place-items:center}.PostAttachmentOpenGraph__image figure{overflow:hidden;max-width:392px;max-height:240px;border-radius:4px}.PostAttachmentOpenGraph__image figure img{min-width:100%;min-height:100%;object-fit:cover}.PostAttachmentOpenGraph__image .preview-toggle{position:absolute;top:-4px;left:-4px;display:flex;width:24px;height:24px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:50%;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;place-content:center;place-items:center}.PostAttachmentOpenGraph__image.collapsed{place-content:start;place-items:start}.PostAttachmentOpenGraph__image.collapsed .preview-toggle{position:relative;top:unset;left:unset;display:flex;width:auto;border:none;border-radius:0;background-color:rgba(0,0,0,0)}.PostAttachmentOpenGraph__image:hover:not(.collapsed) .preview-toggle{display:flex}
.post-image__column--redacted{width:auto;height:auto;min-height:6.4rem;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border:1px solid var(--center-channel-color-16, rgba(63, 67, 80, 0.16));border-radius:4px;background:var(--center-channel-bg, #FFF);box-shadow:var(--elevation-1);cursor:default;gap:16px}.post-image__column--redacted:hover,.post-image__column--redacted:focus-within{box-shadow:none}.post-image__column--redacted-compact{display:flex;height:auto;min-height:unset;align-items:center;padding:6px 10px;gap:8px}.post-image__redacted-icon{position:relative;display:flex;flex-shrink:0;align-items:center;justify-content:center}.post-image__redacted-icon::after{position:absolute;top:55%;left:50%;color:rgba(var(--center-channel-color-rgb), 0.64);content:"?";font-size:13px;font-weight:600;line-height:1;pointer-events:none;transform:translate(-50%, -50%)}.post-image__redacted-details{display:flex;min-width:0;flex:1;flex-direction:column;justify-content:center;gap:2px}.post-image__redacted-title{color:var(--center-channel-color-72, rgba(63, 67, 80, 0.72));font-size:14px;font-style:italic;font-weight:600;line-height:20px}.post-image__redacted-subtitle{color:var(--center-channel-color-56, rgba(63, 67, 80, 0.56));font-size:12px;font-style:italic;font-weight:400;line-height:16px;white-space:normal;word-break:break-word}.post-image__column--redacted-compact .post-image__redacted-title{font-size:12px;line-height:16px}
.SelectProperty{display:flex;align-items:center;padding:3px 12px;border-radius:4px;font-weight:600;gap:6px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.TeamIcon__content{display:flex;overflow:hidden;height:100%;flex-direction:column;justify-content:center;border-radius:8px;transition:all .25s ease}.TeamIcon__content.no-hover{transition:none}.TeamIcon__initials{font-family:Metropolis,sans-serif;letter-spacing:.02em;user-select:none}.TeamIcon__initials.TeamIcon__initials__lg{font-size:3em}.TeamIcon__initials.TeamIcon__initials__sm{font-size:14px}.TeamIcon{position:relative;width:34px;height:34px;box-sizing:content-box;border:3px solid hsla(0,0%,100%,0);border-radius:8px;background-color:rgba(var(--sidebar-text-rgb), 0.16);font-weight:600;text-align:center;text-transform:uppercase;transform-origin:center center;transition:box-shadow .3s,background-color .3s,border-color .3s;will-change:box-shadow,background-color,border-color}.TeamIcon:not(.no-hover):hover{border-color:var(--sidebar-teambar-bg);background-color:rgba(var(--sidebar-text-rgb), 0.3);box-shadow:0 0 0 3px rgba(var(--sidebar-text-rgb), 0.3)}.TeamIcon:active{border-color:var(--sidebar-teambar-bg);box-shadow:0 0 0 3px var(--sidebar-text-active-border)}.TeamIcon.active{border-color:var(--sidebar-teambar-bg);background-color:rgba(var(--sidebar-text-rgb), 0.3);box-shadow:0 0 0 3px var(--sidebar-text-active-border)}.TeamIcon.TeamIcon__lg{width:94px;height:94px}.TeamIcon.TeamIcon__sm{width:34px;height:34px}.TeamIcon.TeamIcon__xsm{width:32px;height:32px}.TeamIcon.TeamIcon__xxs{width:26px;height:26px}.TeamIcon.withImage{border:none}.TeamIcon.withImage.TeamIcon__lg{width:100px;height:100px}.TeamIcon.withImage.TeamIcon__sm{width:40px;height:40px}.TeamIcon.withImage.TeamIcon__xsm{width:32px;height:32px}.TeamIcon.withImage.TeamIcon__xxs{width:26px;height:26px}.TeamIcon.withImage .TeamIcon__image{border-radius:8px;transition:box-shadow 200ms}.TeamIcon.withImage:not(.no-hover):hover{box-shadow:0 0 0 3px hsla(0,0%,100%,.32)}.TeamIcon.withImage:not(.no-hover):hover .TeamIcon__image{box-shadow:inset 0 0 0 3px var(--sidebar-teambar-bg)}.TeamIcon.withImage.active{box-shadow:0 0 0 3px rgba(var(--sidebar-text-active-border-rgb), 0.75)}.TeamIcon.withImage.active .TeamIcon__image{box-shadow:inset 0 0 0 3px var(--sidebar-teambar-bg)}.TeamIcon .TeamIcon__image{overflow:hidden;width:100%;height:100%;background-color:#fff;background-repeat:unset;background-size:100% 100%}
.TeamPropertyRenderer{display:flex;flex-direction:row;align-items:baseline;gap:8px}.TeamPropertyRenderer .TeamIcon{width:20px;height:20px;background:var(--center-channel-color-08);font-size:12px}
.SelectableUserPropertyRenderer .UserMultiSelector .UserMultiSelector__control{height:32px;min-height:unset;align-items:baseline;border:none !important;box-shadow:none !important}.SelectableUserPropertyRenderer .UserMultiSelector .UserMultiSelector__control .UserMultiSelector__indicators{height:32px}.SelectableUserPropertyRenderer .UserMultiSelector .UserMultiSelector__control .UserMultiSelector__value-container{padding:0}.SelectableUserPropertyRenderer .UserMultiSelector .UserMultiSelector__control .UserMultiSelector__value-container .SelectableUserPropertyRenderer_placeholder{display:flex;align-items:center;gap:8px}.SelectableUserPropertyRenderer .UserMultiSelector .UserMultiSelector__control .UserMultiSelector__value-container .SelectableUserPropertyRenderer_placeholder i.icon.icon-account-outline{width:24px;min-width:24px;height:24px;padding:0;border-radius:50%;margin:0;background:rgba(var(--center-channel-color-rgb), 0.12);font-size:12px}.UserMultiSelector__menu-portal{z-index:22 !important}.UserMultiSelector__menu-portal .UserMultiSelector__menu{min-width:200px;max-width:400px;margin-top:0 !important}.UserMultiSelector__menu-portal .UserMultiSelector__menu .UserMultiSelector__control{min-height:unset;max-height:32px;align-items:baseline}.UserMultiSelector__menu-portal .UserMultiSelector__menu .UserMultiSelector__indicators{height:32px}
.UserProfilePill{display:flex;align-items:center;border-radius:12px;background:var(--center-channel-color-08);color:var(--center-channel-color);font-size:12px;font-weight:600;gap:5px;padding-inline:6px}.GroupIcon{display:flex;width:16px;height:16px;flex-shrink:0;align-items:center;justify-content:center;border-radius:50%;background-color:rgba(var(--center-channel-color-rgb), 0.16);color:rgba(var(--center-channel-color-rgb), 0.56);font-size:10px;font-weight:600}.GroupIcon--chip{width:16px;height:16px;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.64)}.GroupLabel{display:flex;align-items:center;gap:4px}.GroupSource{opacity:.64}.Remove{cursor:pointer}.Remove svg{margin-top:4px;fill:var(--center-channel-color-32)}
.UserOptionComponent{display:flex;align-items:center;padding:8px 14px;cursor:pointer;gap:8px}.UserOptionComponent:hover{background:var(--center-channel-color-08)}.UserOptionComponent .GroupIcon{display:flex;width:20px;height:20px;flex-shrink:0;align-items:center;justify-content:center;border-radius:50%;background-color:rgba(var(--center-channel-color-rgb), 0.16);color:var(--center-channel-color);font-size:10px;font-weight:600}.UserOptionComponent .GroupLabel{display:flex;align-items:center;gap:4px}.UserOptionComponent .GroupSource{opacity:.64}
.adminConsoleListTableContainer{overflow:auto}table.adminConsoleListTable{width:100%}table.adminConsoleListTable thead{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08)}table.adminConsoleListTable thead tr{color:rgba(var(--sys-center-channel-color-rgb), 0.64);font-size:12px;font-weight:600;line-height:16px;text-wrap:nowrap;white-space:nowrap}table.adminConsoleListTable thead tr th{background-color:var(--sys-center-channel-bg);padding-block-end:12px;padding-block-start:12px;vertical-align:middle}table.adminConsoleListTable thead tr th:first-child{padding-inline-end:12px;padding-inline-start:24px}table.adminConsoleListTable thead tr th:not(:first-child):not(:last-child){padding-inline-end:12px;padding-inline-start:12px}table.adminConsoleListTable thead tr th:last-child{padding-inline-end:24px;padding-inline-start:12px}table.adminConsoleListTable thead tr th.pinned{position:sticky;z-index:1;right:0;left:0;background-color:var(--sys-center-channel-bg)}table.adminConsoleListTable thead tr th.pinned:first-child{left:0}table.adminConsoleListTable thead tr th.pinned:first-child::after{position:absolute;top:0;right:0;bottom:0;width:1px;background-color:rgba(var(--center-channel-color-rgb), 0.08);content:""}table.adminConsoleListTable thead tr th.pinned:last-child{right:0}table.adminConsoleListTable thead tr th.pinned:last-child::before{position:absolute;top:0;bottom:0;left:0;width:1px;background-color:rgba(var(--center-channel-color-rgb), 0.08);content:""}table.adminConsoleListTable thead tr th.pinned>span{font-size:14px;font-weight:400;line-height:14px}table.adminConsoleListTable thead tr th.sortable:hover{background-color:#f0f0f0;cursor:pointer}table.adminConsoleListTable thead tr th.sortable:hover>span.hoverSortingIcon{visibility:visible}table.adminConsoleListTable thead tr th.sortable>span{font-size:14px;font-weight:400;line-height:14px}table.adminConsoleListTable thead tr th.sortable>span.hoverSortingIcon{color:rgba(var(--sys-center-channel-color-rgb), 0.32);visibility:hidden}table.adminConsoleListTable tbody tr{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);background-color:var(--sys-center-channel-bg);color:var(--sys-center-channel-color);font-size:14px;font-weight:400;line-height:20px}table.adminConsoleListTable tbody tr.clickable:hover{background-color:#f0f0f0;cursor:pointer}table.adminConsoleListTable tbody tr.clickable:hover td.pinned{background-color:#f0f0f0}table.adminConsoleListTable tbody tr.clickable:hover td.noRows{background-color:var(--sys-center-channel-bg);cursor:default}table.adminConsoleListTable tbody tr td{overflow:hidden;padding-block-end:16px;padding-block-start:16px;text-overflow:ellipsis;white-space:nowrap}table.adminConsoleListTable tbody tr td:first-child{padding-inline-end:12px;padding-inline-start:24px}table.adminConsoleListTable tbody tr td:not(:first-child):not(:last-child){padding-inline-end:12px;padding-inline-start:12px}table.adminConsoleListTable tbody tr td:last-child{padding-inline-end:24px;padding-inline-start:12px}table.adminConsoleListTable tbody tr td.pinned{position:sticky;z-index:1;overflow:visible;background-color:var(--sys-center-channel-bg)}table.adminConsoleListTable tbody tr td.pinned:first-child{left:0}table.adminConsoleListTable tbody tr td.pinned:first-child::after{position:absolute;top:0;right:0;bottom:0;width:1px;background-color:rgba(var(--center-channel-color-rgb), 0.08);content:""}table.adminConsoleListTable tbody tr td.pinned:last-child{right:0}table.adminConsoleListTable tbody tr td.pinned:last-child::before{position:absolute;top:0;bottom:0;left:0;width:1px;background-color:rgba(var(--center-channel-color-rgb), 0.08);content:""}table.adminConsoleListTable tbody tr td.noRows{text-align:center}table.adminConsoleListTable tfoot{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08)}table.adminConsoleListTable .dragHandle{position:absolute;top:0;left:0;display:inline-flex;width:24px;height:calc(100% - 1px);color:rgba(var(--center-channel-color-rgb), 0.64)}table.adminConsoleListTable .dragHandle svg{align-self:center}.adminConsoleListTabletOptionalFoot,.adminConsoleListTabletOptionalHead{position:sticky;z-index:1;left:0;display:flex;flex-direction:row;align-items:center;justify-content:space-between;color:rgba(var(--sys-center-channel-color-rgb), 0.6);font-size:14px;font-weight:400;line-height:normal;padding-block-end:12px;padding-block-start:12px;padding-inline-end:24px;padding-inline-start:24px}.adminConsoleListTabletOptionalFoot .adminConsoleListTablePageSize,.adminConsoleListTabletOptionalHead .adminConsoleListTablePageSize{display:flex;flex-direction:row;flex-grow:1;align-items:center;justify-content:flex-end;justify-self:flex-end;margin-inline-end:12px}.adminConsoleListTabletOptionalFoot .adminConsoleListTablePageSize>.react-select,.adminConsoleListTabletOptionalHead .adminConsoleListTablePageSize>.react-select{min-width:72px;margin:0 6px}.adminConsoleListTabletOptionalFoot .adminConsoleListTablePageSize>.react-select .react-select__value-container,.adminConsoleListTabletOptionalHead .adminConsoleListTablePageSize>.react-select .react-select__value-container{color:rgba(var(--sys-center-channel-color-rgb), 1)}.adminConsoleListTabletOptionalFoot .adminConsoleListTablePageSize>.react-select .react-select__menu-list,.adminConsoleListTabletOptionalHead .adminConsoleListTablePageSize>.react-select .react-select__menu-list{color:rgba(var(--sys-center-channel-color-rgb), 1)}.adminConsoleListTabletOptionalFoot .paginationButtons,.adminConsoleListTabletOptionalHead .paginationButtons{display:flex;flex-direction:row;align-items:center;justify-content:center}.adminConsoleListTabletOptionalFoot .paginationButtons>span,.adminConsoleListTabletOptionalHead .paginationButtons>span{padding-inline-end:12px}
.DropdownInput .Input_wrapper{padding:0 1px}.DropdownInput .Input{font-size:14px;line-height:20px}.DropdownInput .Input.Input___focus .a11y--focused{box-shadow:none}.DropdownInput .Input_legend{margin-left:8px}.asyncTeamSelectInput__controlContainer .DropDown__control{background-color:var(--center-channel-bg)}.DropDown__menu{background-color:var(--center-channel-bg) !important}.DropDown__single-value{color:var(--center-channel-color) !important}.asyncTeamSelectInput__indicatorsContainer{margin-right:8px}.asyncTeamSelectInput__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.asyncTeamSelectInput__indicatorsContainer i::before{margin:0}.asyncTeamSelectInput__option>div{padding:10px 24px;cursor:pointer;line-height:16px}.asyncTeamSelectInput__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.asyncTeamSelectInput__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}
.UserMultiSelector{width:100%}.UserMultiSelector__menu-list{display:flex;flex-direction:column}.UserMultiSelector__value-container{display:flex;gap:8px}.UserMultiSelector.singleSelect .UserMultiSelector__value-container{display:flex}.UserMultiSelector__menu{width:max-content !important;min-width:100% !important}
.UserPropertyRenderer{display:flex;flex-direction:row;gap:8px}
.field{display:flex;flex:1 0 0;padding:6px 8px}
.PropertyCardView{display:flex;flex-direction:column;gap:20px}.PropertyCardView .PropertyCardView_title{color:var(--center-channel-color, #3F4350);font-size:25px;font-weight:600}.PropertyCardView .PropertyCardView_fields{display:flex;flex-direction:column;gap:8px}.PropertyCardView .PropertyCardView_fields>.row{display:flex;min-height:32px;flex-direction:row;align-items:start;margin:0;gap:16px}.PropertyCardView .PropertyCardView_fields>.row::before{content:none}.PropertyCardView .PropertyCardView_fields>.row>.field{display:flex;min-width:110px;max-width:110px;align-items:center;color:var(--center-channel-color, #3F4350);font-size:12px;font-weight:600}.PropertyCardView .PropertyCardView_fields>.row>.value{display:flex;min-height:32px;align-items:center}
.DataSpillageReport{max-width:700px;border-radius:4px;background:var(--center-channel-bg, #FFF);box-shadow:0 2px 3px 0 rgba(0,0,0,.08)}#rhsContainer .DataSpillageReport{box-shadow:none}.DataSpillageReport.mode_short{padding:16px 19px;border:1px solid rgba(var(--center-channel-color-rgb), 0.12);border-left:3px solid var(--error-text, #5D89EA)}#rhsContainer .post__body:has(.DataSpillageReport){position:relative;left:-44px;width:calc(100% + 44px) !important;margin-top:25px}#rhsContainer .post:not(.post--editing):not(.post--editing):has(.DataSpillageReport):hover{background-color:unset}
.agent-dropdown{display:flex;align-items:center;gap:8px}.agent-dropdown .agent-dropdown-label{color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans",sans-serif;font-size:11px;font-weight:600;letter-spacing:.48px;line-height:16px;text-transform:uppercase}.agent-dropdown .agent-dropdown-button{display:flex;align-items:center;padding:2px 4px 2px 6px;border:none;border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer;gap:4px;transition:background-color .15s ease}.agent-dropdown .agent-dropdown-button:hover:not(:disabled){background-color:rgba(var(--center-channel-color-rgb), 0.12)}.agent-dropdown .agent-dropdown-button:active:not(:disabled){background-color:rgba(var(--button-bg-rgb), 0.12)}.agent-dropdown .agent-dropdown-button:disabled{cursor:not-allowed;opacity:.5}.agent-dropdown .agent-dropdown-button .agent-dropdown-button-text{color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:11px;font-weight:600;line-height:16px;white-space:nowrap}.agent-dropdown .agent-dropdown-button svg{color:var(--center-channel-color)}.agent-dropdown-menu-header{padding:6px 20px;background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600;letter-spacing:.48px;line-height:16px;text-transform:uppercase}#agent-dropdown-menu{padding:8px 0}#agent-dropdown-menu .MuiMenuItem-root{min-height:40px;padding:8px 16px !important}#agent-dropdown-menu .MuiMenuItem-root .leading-element{width:24px;height:24px;padding:0 4px;margin-inline-end:8px !important}#agent-dropdown-menu .MuiMenuItem-root .label-elements{padding:2px 4px;gap:0 !important}#agent-dropdown-menu .MuiMenuItem-root .label-elements span{color:var(--center-channel-color) !important;font-family:"Open Sans",sans-serif;font-size:14px !important;font-weight:400;line-height:20px}#agent-dropdown-menu .MuiMenuItem-root .trailing-elements{margin-inline-start:0 !important}#agent-dropdown-menu .MuiMenuItem-root .trailing-elements svg{width:16px;height:16px;color:var(--button-bg) !important}
.ai-actions-submenu .MuiPaper-root{min-width:260px;margin-block-start:0}.ai-actions-submenu.ai-actions-submenu-rewrite .MuiPaper-root{min-width:400px}.rewrite-menu-header{min-width:400px;padding:8px 12px 8px 12px}.rewrite-menu-header .Input_wrapper{padding-left:8px}.rewrite-menu-header .Input_legend{display:none}.rewrite-menu-header .Input_container .Input_wrapper>:not(:first-child){margin-left:10px}.rewrite-menu-header .agent-dropdown{margin-bottom:12px}.rewrite-menu-header .rewrite-menu-header-processing{display:flex;align-items:center;padding:4px 4px 0 4px;gap:6px}.rewrite-menu-header .rewrite-menu-header-processing>i,.rewrite-menu-header .rewrite-menu-header-processing>span{color:var(--center-channel-color)}.rewrite-menu-header .rewrite-menu-header-processing>span{font-size:14px;font-weight:400;line-height:20px}.rewrite-menu-header .rewrite-menu-header-processing button{margin-left:auto;background:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.75)}.rewrite-menu-header .rewrite-menu-header-processing button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.rewrite-menu-footer{padding:12px 14px 8px;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.rewrite-menu-footer .btn-quaternary{background:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.75)}.rewrite-menu-footer .btn-quaternary:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.textarea-wrapper{position:relative}@keyframes rewrite-gradient{0%{background-position:200% 0}100%{background-position:-200% 0}}.rewrite-overlay{position:absolute;z-index:999;top:0;right:0;bottom:0;left:0;border-radius:4px;animation:rewrite-gradient 3.5s linear infinite;background:linear-gradient(92deg, rgba(var(--center-channel-bg-rgb), 0.32) 0%, rgba(var(--center-channel-bg-rgb), 0.32) 40%, var(--center-channel-bg) 50%, rgba(var(--center-channel-bg-rgb), 0.32) 60%, rgba(var(--center-channel-bg-rgb), 0.32) 100%);background-size:300% 100%;pointer-events:none}#rewrite-button{pointer-events:auto}
.HelpButton{display:flex;height:20px;justify-content:flex-end}.HelpButton__link{padding:0;border:none;background:none;color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;font-size:12px;text-decoration:none}.HelpButton__link:hover{color:var(--button-bg);text-decoration:underline}.HelpButton__link:focus{outline:none}.HelpButton__link:focus-visible{border-radius:2px;outline:2px solid var(--button-bg);outline-offset:2px}
.DMUserTimezone{margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px}
.date-time-picker-modal .modal-body{overflow:visible}
ul#dropdown_send_post_options li[role=menuitem][aria-disabled=true]{opacity:1}ul#dropdown_send_post_options li[role=menuitem][aria-disabled=true] .label-elements{font-weight:bold}ul#dropdown_send_post_options li.core-menu-options{display:flex;flex-direction:column;align-items:baseline}ul#dropdown_send_post_options li.core-menu-options .trailing-elements{margin-top:4px;margin-left:0;opacity:.8}
.splitSendButton{display:flex;width:48px;height:32px;flex-direction:row;justify-content:center;border-radius:4px;background:var(--button-bg);color:var(--button-color)}.splitSendButton.scheduledPost{width:56px}.splitSendButton.disabled{background:rgba(var(--center-channel-color-rgb), 0.08)}.splitSendButton.disabled svg{fill:rgba(var(--center-channel-color-rgb), 0.32)}.splitSendButton.disabled .button_send_post_options{border-color:rgba(var(--center-channel-color-rgb), 0.16)}.splitSendButton .SendMessageButton,.splitSendButton .button_send_post_options{display:flex;flex-direction:column;justify-content:center;border:none;background:none}.splitSendButton .SendMessageButton.disabled,.splitSendButton .button_send_post_options.disabled{cursor:not-allowed}.splitSendButton .SendMessageButton{flex:1;border-radius:4px 0 0 4px;cursor:pointer;padding-inline:7px;place-content:center;place-items:center;transition:color 150ms}.android .splitSendButton .SendMessageButton,.ios .splitSendButton .SendMessageButton{display:flex}.splitSendButton .SendMessageButton.singleAction{border-radius:4px}.splitSendButton .button_send_post_options{width:21px;border-radius:0 4px 4px 0;border-left:1px solid color-mix(in srgb, currentColor 20%, transparent);padding-inline:2px}
.UnifiedLabelsWrapper{display:flex;flex-wrap:wrap;align-items:center;padding-top:16px;gap:8px}.UnifiedLabelsWrapper__close{display:flex;align-items:center;justify-content:center;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;opacity:0;transition:opacity .15s ease,background-color .15s ease,color .15s ease}.UnifiedLabelsWrapper__close svg{display:block}.UnifiedLabelsWrapper:hover .UnifiedLabelsWrapper__close{opacity:1}.UnifiedLabelsWrapper__close:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.UnifiedLabelsWrapper__close:active{background:rgba(var(--center-channel-color-rgb), 0.16)}
.BurnOnReadLabel{display:flex;width:fit-content;align-items:center;padding:0;gap:4px}.BurnOnReadLabel__badge{display:flex;height:16px;align-items:center;padding:0 6px;border-radius:4px;background-color:rgba(var(--error-text-color-rgb), 0.08);color:var(--error-text);font-size:10px;font-weight:600;gap:4px}.BurnOnReadLabel__icon{display:flex;align-items:center;color:var(--error-text);fill:currentColor}.BurnOnReadLabel__close{display:flex;align-items:center;justify-content:center;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;opacity:0;transition:opacity .15s ease,background-color .15s ease,color .15s ease}.BurnOnReadLabel:hover .BurnOnReadLabel__close{opacity:1}.BurnOnReadLabel__close:hover{background-color:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb))}.BurnOnReadLabel__close:active{background-color:rgba(var(--button-bg-rgb), 0.16);color:rgb(var(--button-bg-rgb))}
.BurnOnReadTourTip__title{display:flex;align-items:center;gap:8px}.BurnOnReadTourTip__badge{display:inline-flex;align-items:center;padding:2px 6px;border-radius:3px;background-color:var(--online-indicator);color:var(--button-color);font-size:10px;font-weight:600;letter-spacing:.5px;text-transform:uppercase}.BurnOnReadTourTip__demo{display:flex;border-radius:4px;margin-top:16px !important;background-color:rgba(var(--center-channel-color-rgb), 0.04)}.BurnOnReadTourTip__demo-placeholder{display:flex;align-items:center;justify-content:center;padding:24px;color:rgba(var(--center-channel-color-rgb), 0.56);gap:8px}.BurnOnReadTourTip__demo-icon{font-size:24px}.BurnOnReadTourTip__demo-text{font-size:13px;font-style:italic}
.BurnOnReadControl{position:relative;display:inline-flex;align-items:center}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.PostPriorityPicker{width:324px}.PostPriorityPicker__apply{height:32px;padding:0 16px;font-size:12px;line-height:10px;position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out}.PostPriorityPicker__apply:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.PostPriorityPicker__apply:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.PostPriorityPicker__apply:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.PostPriorityPicker__apply:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.PostPriorityPicker__apply i{display:flex;font-size:18px}.PostPriorityPicker__cancel{height:32px;padding:0 16px;font-size:12px;line-height:10px;display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out}.PostPriorityPicker__cancel:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.PostPriorityPicker__cancel:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.PostPriorityPicker__cancel:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.PostPriorityPicker__cancel i{display:flex;font-size:18px}.PostPriorityPicker__cancel i:first-child::before{margin:0 7px 0 0}.PostPriorityPicker__cancel i:last-child::before{margin:0 0 0 7px}
.priorityLabelsContainer{display:flex;align-items:center;padding:0;gap:6px}.priorityLabelsContainer:hover .priorityLabelsClose{visibility:visible}.priorityLabelsContainer .priorityLabelsAcknowledgements{display:flex;align-items:center;color:var(--online-indicator);font-size:11px;font-weight:600;line-height:16px}.priorityLabelsContainer .priorityLabelsClose{display:flex;align-items:center;justify-content:center;margin-top:-1px;color:rgb(var(--center-channel-color));font-size:17px;opacity:.73;visibility:hidden}.priorityLabelsContainer span.icon{font-size:14px}.priorityLabelsContainer span.icon.icon-bell-ring-outline{color:var(--dnd-indicator)}.priorityLabelsContainer span.icon.icon-check-circle-outline{color:var(--online-indicator)}.priorityLabelsContainer span.icon.icon-check-circle-outline.hasError{color:var(--dnd-indicator)}.priorityLabelsContainer .priorityLabelsError{color:var(--dnd-indicator);font-size:11px;font-weight:600}
.AdvancedTextEditor__skeleton{display:flex;height:122px;align-items:center;justify-content:center;padding-left:10px;border:2px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0 24px 24px;color:rgba(var(--center-channel-color-rgb), 0.75)}.AdvancedTextEditor__skeleton .btn{margin:10px}.AdvancedTextEditor{position:relative;display:flex;width:100%;flex-direction:row;align-items:end;padding:0 24px;margin:0 auto;gap:12px;justify-items:stretch;--right-padding-for-scrollbar: 0px;--right-padding-for-preview-button: 0px}.AdvancedTextEditor__ctr form{padding:unset}.sidebar--right .AdvancedTextEditor{padding-top:12px}.sidebar--right .AdvancedTextEditor .AutoHeight{position:absolute;bottom:0;left:0}.ThreadViewer .AdvancedTextEditor{padding-top:0px}.ThreadViewer .AdvancedTextEditor .AutoHeight{position:absolute;bottom:0;left:0}.AdvancedTextEditor .custom-textarea{height:0;padding-right:calc(16px + var(--right-padding-for-scrollbar) + var(--right-padding-for-preview-button));box-shadow:none}.AdvancedTextEditor .custom-textarea:focus{box-shadow:none}.AdvancedTextEditor .custom-textarea.textbox-preview-area{height:auto;padding-right:20px;white-space:normal}.AdvancedTextEditor .custom-textarea.textbox-preview-area blockquote:before{top:9px}.AdvancedTextEditor.scroll{--right-padding-for-scrollbar: 8px}.AdvancedTextEditor.formatting-bar{--right-padding-for-preview-button: 32px}.AdvancedTextEditor__body{position:relative;max-width:100%;flex:1;border:2px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background-color:var(--center-channel-bg)}.AdvancedTextEditor__body:focus-visible,.AdvancedTextEditor__body:focus-within,.AdvancedTextEditor__body:focus-visible:hover,.AdvancedTextEditor__body:focus-within:hover{border:2px solid rgba(var(--center-channel-color-rgb), 0.32);outline:none;outline-offset:0}.AdvancedTextEditor__body:hover{border:2px solid rgba(var(--center-channel-color-rgb), 0.24)}.AdvancedTextEditor__action-button{display:flex;width:32px;height:32px;flex-shrink:0;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;fill:currentColor}.AdvancedTextEditor__action-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8);fill:currentColor;text-decoration:none}.AdvancedTextEditor__action-button.hidden{visibility:hidden}.AdvancedTextEditor__action-button+input{position:absolute;top:0;right:0;width:100%;height:100%;margin:0;cursor:pointer;direction:ltr;font-size:23px;opacity:0;pointer-events:none}.AdvancedTextEditor__action-button--active{background:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb));fill:currentColor}.AdvancedTextEditor__cell{position:relative;display:flex;flex-direction:column;vertical-align:top}.AdvancedTextEditor__helper-text{display:inline-block;margin:8px 0 4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans",sans-serif}.AdvancedTextEditor__footer{position:relative;display:flex;flex-direction:row;justify-content:space-between;padding:0 24px;font-size:12px}.AdvancedTextEditor__footer .help__text{text-align:right}.AdvancedTextEditor__footer .help__text a,.AdvancedTextEditor__footer .help__text button{margin-left:10px}.AdvancedTextEditor__footer .has-error,.AdvancedTextEditor__footer .post-error{margin:4px 0 0 0;color:var(--error-text)}.AdvancedTextEditor__labels{display:flex;flex-wrap:wrap;align-items:center;padding-left:16px;gap:8px}@media screen and (max-width: 768px){#post-create .AdvancedTextEditor{padding:0}#post-create .AdvancedTextEditor__body{border-radius:0;border-right:none;border-left:none}#post-create .AdvancedTextEditor__body:focus-visible,#post-create .AdvancedTextEditor__body:focus-within,#post-create .AdvancedTextEditor__body:focus-visible:hover,#post-create .AdvancedTextEditor__body:focus-within:hover,#post-create .AdvancedTextEditor__body:hover{border-right:none;border-left:none}.ThreadViewer #post-create .AdvancedTextEditor .msg-typing:empty{display:none}.sidebar--right .post-create__container form{padding:0}}.msg-typing{display:block;overflow:hidden;height:20px;margin-bottom:5px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;text-overflow:ellipsis;white-space:nowrap}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.channel-invite__wrapper{display:flex;width:100%;flex-direction:column;gap:16px}.channel-invite__content{padding:0}.channel-invite__content .multi-select__container,.channel-invite__content .multi-select__error{padding:0 !important}.channel-invite__content .multi-select__footer{padding:24px 0 !important}.channel-invite__content .multi-select__wrapper{margin:-10px 0 0 -5px !important}.channel-invite__content .invite-as-guest{margin-right:0 !important}.channel-invite__username{font-size:12px}.channel-invite__user-mapping{position:absolute;right:20px}.channel-invite__policy-banner .TagGroup{margin-top:12px}
.AlertBanner{display:flex;align-items:flex-start;padding:14px;border:1px solid;border-radius:4px}.AlertBanner__message{margin-top:8px}.AlertBanner__footerMessage{margin-top:16px}.AlertBanner__message,.AlertBanner__footerMessage{line-height:20px}.AlertBanner__icon{font-size:24px;line-height:24px}.AlertBanner__icon i{display:contents}.AlertBanner__icon i::before{margin:0}.AlertBanner__body{flex-flow:column;flex-grow:1;flex-shrink:1;margin-left:10px;font-size:14px}.AlertBanner__title{font-weight:600;line-height:24px}.AlertBanner__actionButtons{margin-top:20px;margin-bottom:16px;font-family:"Open Sans"}.AlertBanner__actionButtons .AlertBanner__buttonLeft{padding:10px 16px;border:none;border-radius:4px;background:var(--button-bg);color:#fff;font-size:12px;font-weight:600}.AlertBanner__actionButtons .AlertBanner__buttonLeft:hover{background:#1156b2}.AlertBanner__actionButtons .AlertBanner__buttonRight{padding:10px 16px;border:none;border-radius:4px;margin-left:4px;background:rgba(28,88,217,.08);color:#1c58d9}.AlertBanner__actionButtons .AlertBanner__buttonRight:hover{background:rgba(28,88,217,.1215686275)}.AlertBanner__closeButton{display:flex;padding:3px;border:none;border-radius:4px;background:none}.AlertBanner__closeButton:hover{background:rgba(0,0,0,.08)}.AlertBanner--app.danger{border-color:rgba(var(--error-text-color-rgb), 0.24);background:rgba(var(--error-text-color-rgb), 0.08)}.AlertBanner--app.danger .AlertBanner__icon{color:var(--error-text)}.AlertBanner--app.info{border-color:rgba(var(--sidebar-text-active-border-rgb), 0.24);background:rgba(var(--sidebar-text-active-border-rgb), 0.08)}.AlertBanner--app.info .AlertBanner__icon{color:var(--sidebar-text-active-border)}.AlertBanner--app.warning{border-color:rgba(var(--away-indicator-rgb), 0.24);background:rgba(var(--away-indicator-rgb), 0.08)}.AlertBanner--app.warning .AlertBanner__icon{color:var(--away-indicator)}.AlertBanner--app.success{border-color:rgba(var(--online-indicator-rgb), 0.16);background:rgba(var(--online-indicator-rgb), 0.08)}.AlertBanner--app.success .AlertBanner__icon{color:var(--online-indicator)}.AlertBanner--app .AlertBanner__body{color:var(--center-channel-color)}.AlertBanner--app .AlertBanner__closeButton{color:rgba(var(--center-channel-color-rgb), 0.64)}.AlertBanner--sys.danger{border-color:rgba(var(--sys-error-text-color-rgb), 0.24);background:rgba(var(--sys-error-text-color-rgb), 0.08)}.AlertBanner--sys.danger .AlertBanner__icon{color:var(--sys-error-text)}.AlertBanner--sys.info{border-color:rgba(var(--sys-sidebar-text-active-border-rgb), 0.24);background:rgba(var(--sys-sidebar-text-active-border-rgb), 0.08)}.AlertBanner--sys.info .AlertBanner__icon{color:var(--sys-sidebar-text-active-border)}.AlertBanner--sys.warning{border-color:rgba(var(--sys-away-indicator-rgb), 0.24);background:rgba(var(--sys-away-indicator-rgb), 0.08)}.AlertBanner--sys.warning .AlertBanner__icon{color:var(--sys-away-indicator)}.AlertBanner--sys.success{border-color:rgba(var(--sys-online-indicator-rgb), 0.16);background:rgba(var(--sys-online-indicator-rgb), 0.08)}.AlertBanner--sys.success .AlertBanner__icon{color:var(--sys-online-indicator)}.AlertBanner--sys .AlertBanner__body{color:var(--sys-center-channel-color)}.AlertBanner--sys .AlertBanner__closeButton{color:rgba(var(--sys-center-channel-color-rgb), 0.75)}
.AlertTag{display:inline-flex;overflow:hidden;max-width:100%;align-items:center;border-radius:4px;margin-bottom:8px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.AlertTag:is(button){padding:0;border:none;background:none;font:inherit;outline:inherit}.AlertTag--clickable{cursor:pointer}.AlertTag--clickable:hover{opacity:.8}.AlertTag--default{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:var(--center-channel-color)}.AlertTag--primary{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.AlertTag--secondary{background-color:rgba(var(--button-color-rgb), 0.08);color:var(--button-color)}.AlertTag--info{background-color:rgba(var(--info-color-rgb), 0.08);color:var(--info-color)}.AlertTag--small{height:16px;padding:0 6px;font-size:10px}.AlertTag--medium{height:20px;padding:2px 8px;font-size:12px}.AlertTag--large{height:24px;padding:4px 12px;font-size:14px}
.TagGroup{display:flex;flex-wrap:wrap;gap:8px}
[data-simplebar]{position:relative;flex-direction:column;flex-wrap:wrap;justify-content:flex-start;align-content:flex-start;align-items:flex-start}.simplebar-wrapper{overflow:hidden;width:inherit;height:inherit;max-width:inherit;max-height:inherit}.simplebar-mask{direction:inherit;position:absolute;overflow:hidden;padding:0;margin:0;left:0;top:0;bottom:0;right:0;width:auto!important;height:auto!important;z-index:0}.simplebar-offset{direction:inherit!important;box-sizing:inherit!important;resize:none!important;position:absolute;top:0;left:0;bottom:0;right:0;padding:0;margin:0;-webkit-overflow-scrolling:touch}.simplebar-content-wrapper{direction:inherit;box-sizing:border-box!important;position:relative;display:block;height:100%;width:auto;max-width:100%;max-height:100%;overflow:auto;scrollbar-width:none;-ms-overflow-style:none}.simplebar-content-wrapper::-webkit-scrollbar,.simplebar-hide-scrollbar::-webkit-scrollbar{display:none;width:0;height:0}.simplebar-content:after,.simplebar-content:before{content:' ';display:table}.simplebar-placeholder{max-height:100%;max-width:100%;width:100%;pointer-events:none}.simplebar-height-auto-observer-wrapper{box-sizing:inherit!important;height:100%;width:100%;max-width:1px;position:relative;float:left;max-height:1px;overflow:hidden;z-index:-1;padding:0;margin:0;pointer-events:none;flex-grow:inherit;flex-shrink:0;flex-basis:0}.simplebar-height-auto-observer{box-sizing:inherit;display:block;opacity:0;position:absolute;top:0;left:0;height:1000%;width:1000%;min-height:1px;min-width:1px;overflow:hidden;pointer-events:none;z-index:-1}.simplebar-track{z-index:1;position:absolute;right:0;bottom:0;pointer-events:none;overflow:hidden}[data-simplebar].simplebar-dragging{pointer-events:none;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}[data-simplebar].simplebar-dragging .simplebar-content{pointer-events:none;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}[data-simplebar].simplebar-dragging .simplebar-track{pointer-events:all}.simplebar-scrollbar{position:absolute;left:0;right:0;min-height:10px}.simplebar-scrollbar:before{position:absolute;content:'';background:#000;border-radius:7px;left:2px;right:2px;opacity:0;transition:opacity .2s .5s linear}.simplebar-scrollbar.simplebar-visible:before{opacity:.5;transition-delay:0s;transition-duration:0s}.simplebar-track.simplebar-vertical{top:0;width:11px}.simplebar-scrollbar:before{top:2px;bottom:2px;left:2px;right:2px}.simplebar-track.simplebar-horizontal{left:0;height:11px}.simplebar-track.simplebar-horizontal .simplebar-scrollbar{right:auto;left:0;top:0;bottom:0;min-height:0;min-width:10px;width:auto}[data-simplebar-direction=rtl] .simplebar-track.simplebar-vertical{right:auto;left:0}.simplebar-dummy-scrollbar-size{direction:rtl;position:fixed;opacity:0;visibility:hidden;height:500px;width:500px;overflow-y:hidden;overflow-x:scroll;-ms-overflow-style:scrollbar!important}.simplebar-dummy-scrollbar-size>div{width:200%;height:200%;margin:10px 0}.simplebar-hide-scrollbar{position:fixed;left:0;visibility:hidden;overflow-y:scroll;scrollbar-width:none;-ms-overflow-style:none}

.simplebar-track{pointer-events:all}.simplebar-track .simplebar-scrollbar::before{width:6px;border-radius:2px;background-color:rgba(var(--scrollbar-color, var(--sidebar-text-rgb)), 0.32)}.simplebar-track .simplebar-scrollbar.simplebar-visible::before{opacity:1}[data-simplebar]{min-height:0}
.channel_banner{display:flex;width:100%;min-height:24px;max-height:24px;align-items:center;justify-content:center;padding-block:2px;padding-inline:24px;white-space:nowrap}.channel_banner .channel_banner_text{display:block;overflow:hidden;max-width:100%;font-size:13px;line-height:20px;text-align:center;text-overflow:ellipsis}.channel_banner .channel_banner_text a{color:var(--channel-banner-text-color);text-decoration:underline}.channel_banner .channel_banner_text .emoticon{width:16px;min-width:16px;height:16px;min-height:16px}.channel_banner .channel_banner_text .emoticon--unicode{font-size:16px;line-height:20px}.channel_banner .channel_banner_text .markdown__heading{overflow:hidden;margin:2px;font-size:16px;text-overflow:ellipsis}.channel_banner .channel_banner_text :first-child{overflow:hidden;text-overflow:ellipsis}.channel_banner .channel_banner_text .markdown__table{background:unset}.channelBannerTooltip{top:-2px !important;overflow:auto;min-width:400px;max-width:min(1000px,70vw);max-height:80vh;pointer-events:auto}
.toast{position:absolute;z-index:2;width:calc(100% - 30px);height:32px;border-radius:4px;margin:10px 15px 0;background-color:var(--button-bg);color:var(--button-color);cursor:default;font-size:13px;font-weight:bold;opacity:0;visibility:hidden}.toast svg{fill:var(--button-color);vertical-align:middle}body.enable-animations .toast{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.toast .toast__jump{position:absolute}.toast .toast__jump svg{margin-right:5px;vertical-align:middle}.toast .toast__dismiss{position:absolute;right:0;height:32px;padding:0 8px;cursor:pointer}.toast .toast__dismiss:hover{background-color:rgba(0,0,0,.2)}.toast .toast__dismiss span{line-height:31px}.toast .toast__message{position:absolute;z-index:-1;width:calc(100% - 40px);height:32px;padding-left:10px;line-height:31px;text-align:center}.toast .toast__message.toast__pointer{cursor:pointer}.toast .toast__message.toast__pointer:hover{background-color:rgba(0,0,0,.2)}.toast__visible{opacity:1;visibility:visible}body.enable-animations .toast__visible{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.toast__history{z-index:1;background-color:#d8d8d8;color:#3d3c40}.toast__history svg{fill:rgba(61,60,64,.9)}.toast__red{background-color:#d64946}@media screen and (max-width: 768px){.toast .toast__message{display:inline-block}}.tooltip__shortcut--txt{opacity:.73}
.new-replies-banner{position:absolute;bottom:56px;display:flex;justify-content:center}.new-replies-banner .toast{width:156px}.new-replies-banner .toast .toast__jump~span{margin-left:24px}
.Separator{position:relative;z-index:1;height:1px;margin:0;margin-top:-1em;margin-bottom:1em;pointer-events:none;text-align:center}.Separator::before,.Separator::after{position:absolute;left:0;display:none;width:100%;height:1em;content:""}.Separator::before{bottom:0}.Separator::after{top:0}.Separator.hovered--after::before{display:block;background:#f5f5f5}.Separator.hovered--before::after{display:block;background:#f5f5f5}.Separator .separator__hr{position:relative;z-index:5;top:1em;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.12);margin:0}.Separator .separator__text{position:relative;z-index:5;display:inline-block;padding:0 1em;border-radius:50px;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:13px;font-weight:700;line-height:2em}@media screen and (max-width: 1440px){.Separator.hovered--comment::before,.Separator.hovered--comment::after{background:none !important}}@media screen and (max-width: 768px){.Separator.hovered--after::before{background:none}.Separator.hovered--before::after{background:none}}@media print{.Separator .separator__hr{top:1.7em}}
.post--editing__wrapper{position:relative}.post--editing__wrapper textarea,.post--editing__wrapper #edit_textbox_placeholder{padding:13px 16px 12px 16px;padding-right:50px}.post--editing__wrapper .edit-post-footer.has-error{color:rgb(var(--dnd-indicator-rgb))}.post-edit__container{padding-top:8px;background:rgba(0,0,0,0)}.post-edit__container .AdvancedTextEditor{padding:0}.post-edit__container [data-testid=formattingBarContainer]{background-color:var(--center-channel-bg)}.post-edit__container .custom-textarea{padding:13px 0 12px 16px}.post-edit__container .AdvancedTextEditor__body .AutoHeight{background-color:var(--center-channel-bg)}.post-edit__container .AdvancedTextEditor__footer{padding-inline:0}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.AcknowledgementButton{height:24px;padding:4px 6px;font-size:11px;line-height:16px;position:relative;display:flex;min-width:0;align-items:center;border:0;border-radius:4px;margin:4px 0;background:rgba(var(--online-indicator-rgb), 0.08);color:var(--online-indicator);font-weight:600;transition:all .15s ease-out}.AcknowledgementButton>svg{margin-right:3px;fill:var(--online-indicator)}.AcknowledgementButton--default{padding-right:9px}.AcknowledgementButton--disabled,.AcknowledgementButton:disabled{background:rgba(var(--online-indicator-rgb), 0.08);cursor:default}.AcknowledgementButton:hover:enabled{background:rgba(var(--online-indicator-rgb), 0.12)}.AcknowledgementButton:active:enabled{background:rgba(var(--online-indicator-rgb), 0.16)}.AcknowledgementButton--acked{background:rgba(var(--online-indicator-rgb), 0.8);color:#fff}.AcknowledgementButton--acked>svg{margin-right:3px;fill:#fff}.AcknowledgementButton--acked.AcknowledgementButton--disabled,.AcknowledgementButton--acked.AcknowledgementButton--disabled:hover,.AcknowledgementButton--acked:disabled{background:rgba(var(--online-indicator-rgb), 0.8);color:#fff}.AcknowledgementButton--acked.AcknowledgementButton--disabled>svg,.AcknowledgementButton--acked.AcknowledgementButton--disabled:hover>svg,.AcknowledgementButton--acked:disabled>svg{margin-right:3px;fill:#fff}.AcknowledgementButton--acked:active:enabled:not(.AcknowledgementButton--disabled),.AcknowledgementButton--acked:hover:enabled:not(.AcknowledgementButton--disabled){background:rgb(var(--online-indicator-rgb))}.AcknowledgementButton__divider{width:1px;height:24px;margin:0 4px;background:rgba(var(--center-channel-color-rgb), 0.16)}
.BurnOnReadBadge{position:relative;z-index:25;display:inline-flex;align-items:center;padding:0;border:none;margin-left:8px;background:rgba(0,0,0,0);cursor:pointer;pointer-events:auto;vertical-align:middle}.BurnOnReadBadge:disabled{cursor:default}.BurnOnReadBadge__icon{color:var(--dnd-indicator, #D24B4E)}.BurnOnReadBadge:hover:not(:disabled) .BurnOnReadBadge__icon{opacity:.8}.BurnOnReadBadge__tooltip-content .primary-text{color:#fff}.BurnOnReadBadge__tooltip-content .secondary-text{margin-top:4px;color:hsla(0,0%,100%,.64)}
.BurnOnReadConcealedPlaceholder{display:flex;width:100%;max-width:695px;align-items:center;padding:8px 12px;border:none;border-radius:4px;animation:fadeIn .3s ease;background:var(--center-channel-color-08, rgba(63, 67, 80, 0.08));cursor:pointer;transition:all .3s ease}.BurnOnReadConcealedPlaceholder:disabled{cursor:wait;pointer-events:none}.BurnOnReadConcealedPlaceholder:hover:not(:disabled){background:var(--center-channel-color-16, rgba(63, 67, 80, 0.16))}.BurnOnReadConcealedPlaceholder__content{display:flex;align-items:center;gap:8px}.BurnOnReadConcealedPlaceholder__icon{flex-shrink:0;color:var(--center-channel-color-64, rgba(63, 67, 80, 0.64))}.BurnOnReadConcealedPlaceholder__icon--error{color:var(--error-text, #D24B4E)}.BurnOnReadConcealedPlaceholder__text{color:var(--center-channel-color-64, rgba(63, 67, 80, 0.64));font-size:12px;line-height:20px}.BurnOnReadConcealedPlaceholder__text--error{color:var(--error-text, #D24B4E)}.BurnOnReadConcealedPlaceholder--loading{cursor:wait}.BurnOnReadConcealedPlaceholder--error{animation:fadeIn .3s ease;background:var(--error-text-08, rgba(210, 75, 78, 0.08)) !important;cursor:default}.BurnOnReadConcealedPlaceholder--error:hover{background:var(--error-text-08, rgba(210, 75, 78, 0.08)) !important}@keyframes fadeIn{from{opacity:0;transform:translateY(-4px)}to{opacity:1;transform:translateY(0)}}
.BurnOnReadTimerChip{position:relative;z-index:25;display:inline-flex;height:16px;align-items:center;padding:0px 4px;border:none;border-radius:4px;margin-left:8px;background:var(--error-text-12, rgba(210, 75, 78, 0.12));color:var(--error-text, #d24b4e);cursor:pointer;font-size:10px;font-weight:600;line-height:12px;pointer-events:auto;transition:all .2s ease}.BurnOnReadTimerChip:hover{opacity:.9}.BurnOnReadTimerChip:focus{outline:none}.BurnOnReadTimerChip__icon{display:flex;align-items:center;color:inherit}.BurnOnReadTimerChip__time{min-width:32px;font-variant-numeric:tabular-nums;text-align:center}.BurnOnReadTimerChip--warning{animation:pulse 1s ease-in-out infinite;background:var(--dnd-indicator, #d24b4e);color:#fff}.BurnOnReadTimerChip--expired{animation:fadeOut 2s ease-out forwards}.BurnOnReadTimerChip__tooltip{text-align:center}.BurnOnReadTimerChip__tooltip-primary{color:#fff}.BurnOnReadTimerChip__tooltip-secondary{margin-top:4px;color:hsla(0,0%,100%,.7)}@keyframes pulse{0%,100%{opacity:1}50%{opacity:.85}}@keyframes fadeOut{0%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(0.95)}}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.reaction-emoji--large img{width:48px;max-width:none;height:48px;max-height:none;margin:4px 0}.Reaction{padding:0;border:none;background:rgba(0,0,0,0);display:inline-flex;min-width:28px;height:24px;align-items:center;padding:0 5px;border:1px solid rgba(0,0,0,0);border-radius:4px;margin:0 4px 4px 0;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;fill:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px;font-weight:600;transition:border-color 100ms linear,background-color 100ms linear;user-select:none}.Reaction:focus{outline:0;text-decoration:none}.Reaction.btn{padding:6px 12px}.Reaction.btn--block{width:100%;text-align:left}.Reaction:hover,.Reaction:active{text-decoration:none}.Reaction:hover{border:solid 1px rgba(61,60,64,.16);background-color:rgba(0,0,0,0);color:rgba(61,60,64,.75)}.Reaction:not(.Reaction--reacted):hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.75);fill:rgba(var(--center-channel-color-rgb), 0.75)}.Reaction:not(.Reaction--reacted):active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.Reaction.Reaction--read-only{cursor:default}.Reaction.Reaction__add{position:relative;font-size:20px;line-height:0;vertical-align:middle}.Reaction.Reaction__add.Reaction__add--open{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg);opacity:1;visibility:visible}.Reaction__emoji{min-width:16px;max-width:16px;min-height:16px;max-height:16px;margin:0 2px 0 0;object-fit:contain;vertical-align:middle}.Reaction__emoji--post-menu{width:18px;height:18px;vertical-align:middle}.Reaction__count{display:flex;overflow:hidden;flex-direction:row-reverse;justify-content:flex-start;line-height:16px;pointer-events:none}.Reaction.Reaction--reacted,.Reaction.Reaction--reacting{border-color:var(--button-bg);background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.Reaction.Reaction--reacted:hover,.Reaction.Reaction--reacting:hover{border-color:var(--button-bg);background:var(--center-channel-bg)}.Reaction.Reaction--reacted:active,.Reaction.Reaction--reacting:active{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.Reaction.Reaction--reacting{transition:border-color 200ms ease-in-out}.Reaction.Reaction--reacting .Reaction__number--display{visibility:hidden}.Reaction.Reaction--reacting .Reaction__number--reacted,.Reaction.Reaction--reacting .Reaction__number--unreacted{display:inline-block;animation-duration:200ms;animation-fill-mode:forwards;animation-name:reacted-anim;animation-timing-function:ease-in-out}.Reaction.Reaction--unreacting{transition:border-color 200ms ease-in-out}.Reaction.Reaction--unreacting .Reaction__number--display{visibility:hidden}.Reaction.Reaction--unreacting .Reaction__number--reacted,.Reaction.Reaction--unreacting .Reaction__number--unreacted{display:inline-block;animation-direction:reverse;animation-duration:200ms;animation-fill-mode:forwards;animation-name:reacted-anim;animation-timing-function:ease-in-out}.Reaction .Reaction__number{position:relative}.Reaction .Reaction__number--display{display:inline-block}.Reaction .Reaction__number--reacted{position:absolute;top:100%;left:0;display:none}.Reaction .Reaction__number--unreacted{position:absolute;top:0%;left:0;display:none}@keyframes reacted-anim{from{transform:translateY(0%)}to{transform:translateY(-100%)}}
.Button{position:relative;padding:4px 10px;border-radius:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:Open Sans;font-style:normal;font-weight:600}.Button.ReplyButton{overflow:visible;height:24px;padding-left:8px}.Button.FollowButton{overflow:visible;height:24px}.Button.allowTextOverflow{min-width:4rem}.Button.allowTextOverflow .Button_label{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.Button:hover{text-decoration:none}.Button:disabled{opacity:32%}.Button.Button___transparent{border:none;background:rgba(0,0,0,0)}.Button.Button___transparent:hover:not(:disabled){background:rgba(var(--center-channel-color-rgb), 0.08)}.Button.Button___transparent:active:not(:disabled),.Button.Button___transparent.is-active:not(:disabled){background:rgba(var(--button-bg-rgb), 0.08)}.Button.Button___transparent.is-active:active:not(:disabled),.Button.Button___transparent.is-active:hover:not(:disabled){background:rgba(var(--button-bg-rgb), 0.16)}.Button.Button___transparent.is-active:hover:active:not(:disabled){background:rgba(var(--button-bg-rgb), 0.24)}.Button.Button___transparent:hover:not(:disabled){color:rgba(var(--center-channel-color-rgb), 0.75)}.Button.Button___transparent:active:not(:disabled),.Button.Button___transparent.is-active:not(:disabled){color:rgba(var(--button-bg-rgb), 1)}.Button.Button___large{font-size:14px}.Button.Button___large.Button___icon{width:32px;height:32px;padding:7px 0;font-size:18px;line-height:18px}.Button .Button_label{display:inline-block;max-width:100%}.Button .Button_label.margin_top{margin-top:4px}.Button .Button_prepended{margin-right:.4em}.Button .Button_appended{margin-left:.4em}.Button .dot{position:absolute;top:6px;right:6px;width:4px;height:4px;border-radius:50%;background:rgba(var(--sidebar-text-active-border-rgb), 1)}.separated+.separated{margin-left:var(--button-separator-gap, 0)}.separated:not(.Button)+.separated:not(.Button),.separated:not(.Button)+.separated:not(:hover):not(.is-active),.separated:not(:hover):not(.is-active)+.separated:not(.Button),.separated:not(:hover):not(.is-active)+.separated:not(:hover):not(.is-active){position:relative}.separated:not(.Button)+.separated:not(.Button)::before,.separated:not(.Button)+.separated:not(:hover):not(.is-active)::before,.separated:not(:hover):not(.is-active)+.separated:not(.Button)::before,.separated:not(:hover):not(.is-active)+.separated:not(:hover):not(.is-active)::before{position:absolute;top:50%;left:calc(-0.5px - var(--button-separator-gap, 0px)/2);display:inline-block;width:1px;height:var(--button-separator-height, 100%);background:rgba(var(--center-channel-color-rgb), 0.16);content:"";pointer-events:none;transform:translateY(-50%)}
.Avatars{display:inline-flex;flex-flow:nowrap;align-items:center;justify-content:center}.Avatars.Avatars___xxs{--offset: -4px;--border-width: 1px}.Avatars.Avatars___xs{--offset: -5px;--border-width: 1px}.Avatars.Avatars___sm{--offset: -5px;--border-width: 1px}.Avatars.Avatars___md{--offset: -6px;--border-width: 1.5px}.Avatars.Avatars___lg{--offset: -7px;--border-width: 2px}.Avatars.Avatars___xl{--offset: -10px;--border-width: 2px}.Avatars.Avatars___xxl{--offset: -26px;--border-width: 5px}.Avatars>button{transition:all 100ms ease-in-out}.Avatars>button:not(:first-child){margin-left:var(--offset)}.Avatars>button:hover,.Avatars>button:focus{z-index:1;box-shadow:var(--elevation-2);transform:scale(1.2)}.Avatars .Avatar{border:var(--border-width) solid rgba(var(--center-channel-bg-rgb), 1)}.Avatars .Avatar:not(:first-child){margin-left:var(--offset)}.Avatars .Avatar:hover,.Avatars .Avatar:focus{z-index:1;filter:drop-shadow(0 2px 3px rgba(0, 0, 0, 0.08))}.Avatars .Avatar.Avatar-plain[data-content^="+"]::before{text-indent:-4%}
.ThreadFooter{--button-separator-height: 15px;--button-separator-gap: 4px;position:relative;left:-34px;display:inline-flex;width:calc(100% + 15px);align-items:center;padding:4px 0 4px 9px;margin-top:1px;margin-bottom:5px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:15px;white-space:nowrap}.ThreadFooter .indicator{width:24px;height:24px;padding:8px}.ThreadFooter .dot-unreads{width:8px;height:8px;border-radius:50%;background:rgba(var(--sidebar-text-active-border-rgb), 1)}.ThreadFooter .Avatars{margin-right:2px;font-weight:600}.ThreadFooter .icon{width:14px;height:13px;font-size:14px}.ThreadFooter .alt-visible{opacity:0}.ThreadFooter:hover .alt-visible,.ThreadFooter:focus-within .alt-visible,.ThreadFooter.is-active .alt-visible,.post:hover .ThreadFooter .alt-visible,.post:focus-within .ThreadFooter .alt-visible{opacity:1}.ThreadFooter:hover .alt-hidden,.ThreadFooter:focus-within .alt-hidden,.ThreadFooter.is-active .alt-hidden,.post:hover .ThreadFooter .alt-hidden,.post:focus-within .ThreadFooter .alt-hidden{display:none}.ThreadFooter .Timestamp{display:inline-grid;padding-left:1rem;font-weight:400}.ThreadFooter .Timestamp>span{display:inline-block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}
.visit-marketplace-text{padding:8px 16px 12px 16px;text-align:center}.visit-marketplace{padding-right:16px;padding-bottom:8px;padding-left:16px}.visit-marketplace-button{width:100%}.visit-marketplace-button .Menu{padding:8px 0;text-align:left}.ActionsMenuEmptyPopover .MuiPaper-root{min-width:114px;max-width:496px;max-height:80vh;padding:4px 0;background-color:var(--center-channel-bg);box-shadow:var(--elevation-4),0 0 0 1px rgba(var(--center-channel-color-rgb), 0.12) inset;margin-block-start:4px}
.FlagPostModal__section_title{color:var(--center-channel-color);font-size:14px;font-weight:600}.FlagPostModal__post_preview{display:flex;flex-direction:column;gap:8px}.FlagPostModal__body{display:flex;flex-direction:column;gap:24px}.FlagPostModal__section{display:flex;flex-direction:column;gap:8px}.FlagPostModal__section .post.forward-post__post-preview--override{padding:0}.FlagPostModal .FlagPostModal__flagging_reason .FlagPostModal__reason__error-message{display:flex;width:90%;align-items:center;color:var(--error-text);font-size:12px}.FlagPostModal .FlagPostModal__comment #PreviewInputTextButton{position:absolute;z-index:2;top:8px;right:8px}.FlagPostModal .FlagPostModal__comment textarea#FlagPostModal__comment,.FlagPostModal .FlagPostModal__comment .textbox-preview-area{height:110px !important}.FlagPostModal .FlagPostModal__request-error{display:flex;width:90%;align-items:center;color:var(--error-text);font-size:12px}
.forward-post__body{display:flex;overflow:visible;flex-direction:column;color:var(--center-channel-color);gap:24px}.forward-post__body .custom-textarea,.forward-post__body #forward_post_textbox{min-height:40px;padding:10px 16px}.forward-post__body #forward_post_textbox{overflow:auto;border:none;box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.forward-post__body #forward_post_textbox:focus{box-shadow:inset 0 0 0 2px var(--button-bg)}.forward-post__body #forward_post_textbox:focus:not(:focus-visible){box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.forward-post__body #forward_post_textbox:focus:focus-visible{box-shadow:inset 0 0 0 2px var(--button-bg)}.forward-post__select{position:relative}.forward-post__select .option,.forward-post__select .singleValue{top:100%;display:grid;align-content:center;align-items:center;color:var(--center-channel-color);gap:12px;grid-auto-columns:minmax(20%, max-content);grid-template-columns:24px 1fr;grid-template-rows:24px}.forward-post__select .option svg,.forward-post__select .option .status-wrapper,.forward-post__select .option .status--group,.forward-post__select .singleValue svg,.forward-post__select .singleValue .status-wrapper,.forward-post__select .singleValue .status--group{place-self:center}.forward-post__select .option .status--group,.forward-post__select .singleValue .status--group{display:flex;width:1.8rem;height:1.8rem;align-items:center;justify-content:center;margin:0;background-color:rgba(var(--center-channel-color-rgb), 0.12)}.forward-post__select .option .status-wrapper,.forward-post__select .singleValue .status-wrapper{height:2.4rem}.forward-post__select .option__content,.forward-post__select .singleValue__content{display:flex;overflow:hidden;max-width:100%;flex-direction:row;gap:8px}.forward-post__select .option__content--text,.forward-post__select .singleValue__content--text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.forward-post__select .option__content--description,.forward-post__select .singleValue__content--description{color:rgba(var(--center-channel-color-rgb), 0.75)}.forward-post__select .option__content .emoticon,.forward-post__select .singleValue__content .emoticon{margin-left:0}.forward-post__select .option__team-name,.forward-post__select .singleValue__team-name{overflow:hidden;width:100%;color:rgba(var(--center-channel-color-rgb), 0.75);grid-column:3/4;text-align:right;text-overflow:ellipsis;white-space:nowrap}.forward-post__post-preview--title{font-size:12px;font-weight:600;line-height:16px}.forward-post__post-preview--override{padding:2px 0;pointer-events:none}.forward-post__post-preview--override:not(.post--editing):not(.post--editing):hover{background-color:rgba(0,0,0,0)}.forward-post__post-preview--override:not(.post--editing):not(.post--editing):hover .attachment__content.attachment__content--permalink{box-shadow:0 2px 3px rgba(0,0,0,.08)}.console__body .modal .GenericModal.forward-post,.app__body .modal .GenericModal.forward-post{margin-top:64px}.console__body .modal .GenericModal.forward-post .modal-body,.app__body .modal .GenericModal.forward-post .modal-body{max-height:calc(100vh - 128px - 61px - 88px)}.console__body .modal .GenericModal.forward-post .modal-body .form-control,.app__body .modal .GenericModal.forward-post .modal-body .form-control{border:none;box-shadow:none}.console__body .modal .GenericModal.forward-post .modal-body .form-control#forward_post_textbox_placeholder,.app__body .modal .GenericModal.forward-post .modal-body .form-control#forward_post_textbox_placeholder{opacity:.73 !important}.console__body .modal .GenericModal.forward-post .modal-body .post-error,.app__body .modal .GenericModal.forward-post .modal-body .post-error{position:relative;top:3px;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}
.move-thread .modal-body{overflow:visible}.move-thread.modal-dialog{margin-top:64px}.move-thread__body{display:flex;overflow:visible;flex-direction:column;color:var(--center-channel-color);gap:24px}.move-thread__body .custom-textarea,.move-thread__body #move_thread_textbox{min-height:40px;padding:10px 16px}.move-thread__body #move_thread_textbox{overflow:auto;border:none;box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.move-thread__body #move_thread_textbox:focus{box-shadow:inset 0 0 0 2px var(--button-bg)}.move-thread__body #move_thread_textbox:focus:not(:focus-visible){box-shadow:inset 0 0 0 1px rgba(var(--center-channel-color-rgb), 0.16)}.move-thread__body #move_thread_textbox:focus:focus-visible{box-shadow:inset 0 0 0 2px var(--button-bg)}.move-thread__select{position:relative}.move-thread__select .option,.move-thread__select .singleValue{top:100%;display:grid;align-content:center;align-items:center;color:var(--center-channel-color);gap:12px;grid-auto-columns:minmax(20%, max-content);grid-template-columns:24px 1fr;grid-template-rows:24px}.move-thread__select .option svg,.move-thread__select .option .status-wrapper,.move-thread__select .option .status--group,.move-thread__select .singleValue svg,.move-thread__select .singleValue .status-wrapper,.move-thread__select .singleValue .status--group{place-self:center}.move-thread__select .option .status--group,.move-thread__select .singleValue .status--group{display:flex;width:1.8rem;height:1.8rem;align-items:center;justify-content:center;margin:0;background-color:rgba(var(--center-channel-color-rgb), 0.12)}.move-thread__select .option .status-wrapper,.move-thread__select .singleValue .status-wrapper{height:2.4rem}.move-thread__select .option__content,.move-thread__select .singleValue__content{display:flex;overflow:hidden;max-width:100%;flex-direction:row;gap:8px}.move-thread__select .option__content--text,.move-thread__select .singleValue__content--text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.move-thread__select .option__content--description,.move-thread__select .singleValue__content--description{color:rgba(var(--center-channel-color-rgb), 0.56)}.move-thread__select .option__content .emoticon,.move-thread__select .singleValue__content .emoticon{margin-left:0}.move-thread__select .option__team-name,.move-thread__select .singleValue__team-name{overflow:hidden;width:100%;color:rgba(var(--center-channel-color-rgb), 0.56);grid-column:3/4;text-align:right;text-overflow:ellipsis;white-space:nowrap}.move-thread__post-preview--title{font-size:12px;font-weight:600;line-height:16px}.move-thread__post-preview--override{padding:2px 0;pointer-events:none}.move-thread__post-preview--override:not(.post--editing):not(.post--editing):hover{background-color:rgba(0,0,0,0)}.move-thread__post-preview--override:not(.post--editing):not(.post--editing):hover .attachment__content.attachment__content--permalink{box-shadow:0 2px 3px rgba(0,0,0,.08)}.console__body .modal .GenericModal.move-thread,.app__body .modal .GenericModal.move-thread{margin-top:64px}.console__body .modal .GenericModal.move-thread .modal-body,.app__body .modal .GenericModal.move-thread .modal-body{max-height:calc(100vh - 128px - 61px - 88px)}.console__body .modal .GenericModal.move-thread .modal-body .form-control,.app__body .modal .GenericModal.move-thread .modal-body .form-control{border:none;box-shadow:none}.console__body .modal .GenericModal.move-thread .modal-body .form-control#move_thread_textbox_placeholder,.app__body .modal .GenericModal.move-thread .modal-body .form-control#move_thread_textbox_placeholder{opacity:.64 !important}.console__body .modal .GenericModal.move-thread .modal-body .post-error,.app__body .modal .GenericModal.move-thread .modal-body .post-error{position:relative;top:3px;margin-bottom:0;font-size:.85em;font-weight:normal;opacity:.55}
.dot-menu__item-new-badge{display:flex;align-items:center;gap:4px}.dot-menu__post-reminder-menu-header{padding:6px 20px;margin:0;color:var(--center-channel-color);font-weight:bold;pointer-events:none}.dot-menu__item-trailing-icon{display:flex;margin-right:-4px}.flag_post_menu_item i.icon.icon-flag-outline:before{margin:0}
.NotificationSeparator .separator__hr{border-color:#ffaf53}.NotificationSeparator .separator__text{display:inline-flex;color:#f80;font-weight:normal}
.virtual-list__ctr{display:flex;height:100%;flex-direction:column}
.ThreadViewer .post:not(.same--root.same--user) a.post__permalink{position:initial !important;text-align:left !important}.ThreadViewer .post-list__dynamic--RHS{display:flex;height:100%;flex-direction:column;padding-bottom:8px;scrollbar-color:var(--center-channel-color-32) hsla(0,0%,100%,0);scrollbar-width:thin}.ThreadViewer .post-list__dynamic--RHS>div[role=list]:nth-child(1){margin-top:auto}.ThreadViewer>div{flex:1 1 auto}.ThreadViewer .channel-archived-warning__container{padding-top:16px}.ThreadViewer .channel-archived-warning__content{display:flex;justify-content:center;padding:24px;padding-right:47.5px;padding-left:46.5px;margin:0 auto;line-height:20px;text-align:center}.ThreadViewer .channel-archived-warning__content svg{margin-right:3.4px}

/*# sourceMappingURL=2806.d45f96796ecb3dc79242.css.map*/